--
-- Local Variables and Constants
--

--local addonName = ...
--local addon = _G[addonName]
local _L = SetCollectorLocalization

local WOW_VERSION = select(4,GetBuildInfo())
local DB_VERSION = WOW_VERSION

local ANY					=	{ Code = "Z", Description = "Any" }

local DEATHKNIGHT = { Code = "DK", Description = "DEATHKNIGHT" }
local DRUID 			= { Code = "DR", Description = "DRUID" }
local HUNTER 			= { Code = "HU", Description = "HUNTER" }
local MAGE 				= { Code = "MA", Description = "MAGE" }
local MONK 				= { Code = "MO", Description = "MONK" }
local PALADIN 		= { Code = "PA", Description = "PALADIN" }
local PRIEST 			= { Code = "PR", Description = "PRIEST" }
local ROGUE 			= { Code = "RO", Description = "ROGUE" }
local SHAMAN 			= { Code = "SH", Description = "SHAMAN" }
local WARLOCK 		= { Code = "WK", Description = "WARLOCK" }
local WARRIOR 		= { Code = "WR", Description = "WARRIOR" }

local ALLIANCE 		= { Code = "A", Description = "Alliance" }
local HORDE 			= { Code = "H", Description = "Horde" }

local TANK 				= { Code = "T", Description = "TANK" }
local HEALER 			= { Code = "H", Description = "HEALER" }
local CASTER 			= { Code = "C", Description = "CASTER" }
local RANGED 			= { Code = "R", Description = "RANGED" }
local MELEE 			= { Code = "M", Description = "MELEE" }

local OBTAIN			= true
local NOOBTAIN 		= false

local TRANSMOG 		= true
local NOTRANSMOG 	= false

local POOR 			= 0
local COMMON 		= 1
local UNCOMMON 	= 2
local RARE 			= 3
local EPIC 			= 4
local LEGENDARY = 5
local ARTIFACT 	= 6
local HEIRLOOM 	= 7

-- Collection Types
local LEGENDARY 	= { ID = 1, Code = "ZZ", Description = "LEGENDARY" }
local RAID 				= { ID = 2, Code = "TR", Description = "RAID" }
local DUNGEON 		= { ID = 3, Code = "DG", Description = "DUNGEON" }
local CHALLENGE 	= { ID = 4, Code = "CD", Description = "CHALLENGE" }
local PVP 				= { ID = 5, Code = "PV", Description = "PVP" }
local GARRISON 		= { ID = 6, Code = "GA", Description = "GARRISON" }
local HOLIDAY			= { ID = 7, Code = "HO", Description = "HOLIDAY" }
local OTHER				= { ID = 8, Code = "OT", Description = "OTHER" }

--
-- Helper Functions
--

local function GetCount(T)
  local count = 0
  for _ in pairs(T) do count = count + 1 end
  return count
end

local function CreateCollections(version, release)
	SetCollectorDB = {
		[LEGENDARY.ID] 	= { Title = LEGENDARY.Description, Sets = { } },
		[RAID.ID] 			= { Title = RAID.Description, Sets = { } },
		[DUNGEON.ID] 		= { Title = DUNGEON.Description, Sets = { } },
		[CHALLENGE.ID] 	= { Title = CHALLENGE.Description, Sets = { } },
		[PVP.ID] 				= { Title = PVP.Description, Sets = { } },
		[GARRISON.ID] 	= { Title = GARRISON.Description, Sets = { } },
		[HOLIDAY.ID] 		= { Title = HOLIDAY.Description, Sets = { } },
		[OTHER.ID] 			= { Title = OTHER.Description, Sets = { } },
		Items = { },
		version = version,
		release = release
	}
	--print(version)
	--print(release)
end

local function GetTooltipIdentifier(collection, id, title)
	local identifier
	if collection == RAID then
		identifier = "T"..id
	elseif collection == PVP then
		--identifier = "S"..id		-- This seems redundant since the Season is already shown on the tooltip
		identifier = "PVP"
	end
	return identifier
end

local function AddSet(minVersion, maxVersion, collection, id, title, class, role, faction, ...)
	if WOW_VERSION >= minVersion then
		if maxVersion == nil or WOW_VERSION <= maxVersion then
			local tempSet = { }
			tempSet = {
				Title = title,
				TooltipID = GetTooltipIdentifier(collection, id, title),
				Class = class.Description,
				Role = role.Description,
				Faction = faction.Description,
				Name = name,
				Variants = { }
			}
			local ID = collection.Code..string.format("%03d", id)..class.Code..role.Code..faction.Code
			SetCollectorDB[collection.ID].Sets[ID] = tempSet
			return ID
		end
	end
end

local function AddVariant(minVersion, maxVersion, collection, set, title, obtainable, transmogrifiable, ...)
	if WOW_VERSION >= minVersion then
		if maxVersion == nil or WOW_VERSION <= maxVersion then
			local tempItems = { }
			local n = select("#",...)
			for i = 1,n do
				local v = select(i,...)
				tinsert(tempItems,v)
				SetCollectorDB.Items[v] = { collection = collection.ID, set = set, variant = #SetCollectorDB[collection.ID].Sets[set].Variants + 1 }
			end
			local tempVariant = {
				Title = title,
				Obtainable = obtainable,
				Transmogrifiable = transmogrifiable,
				Items = tempItems,
				Count = #tempItems
			}
			tinsert(SetCollectorDB[collection.ID].Sets[set].Variants, tempVariant)	
		end
	end	
end

local function T17(itemID, bonusID)
	local itemString = ""
	if itemID ~= nil and bonusID ~= nil then
		itemString = "item:"..itemID..":0:0:0:0:0:0:0:0:0:0:491:1:"..bonusID
	else
		itemString = itemID
	end
	return itemString
end

local function T18(itemID, bonusID)
	local itemString = ""
	if itemID ~= nil and bonusID ~= nil then
		itemString = "item:"..itemID..":0:0:0:0:0:0:0:0:262:0:6:1:"..bonusID
	else
		itemString = itemID
	end
	return itemString
end

--
-- Class Functions 
--

local function AddDeathKnightSets()
	local set = ""
	
	-- Legendaries
	set = AddSet(60200,nil,LEGENDARY,100,"LG_MELEE_STR_100",DEATHKNIGHT,MELEE,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_MELEE_STR_100",OBTAIN,NOTRANSMOG,124634)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_TANK_100",DEATHKNIGHT,TANK,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_TANK_100",OBTAIN,NOTRANSMOG,124637)
				
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",OBTAIN,TRANSMOG,17182)
	set = AddSet(50400,nil,LEGENDARY,70,"LG_MELEE_70",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_70",OBTAIN,TRANSMOG,32837)
	set = AddSet(50400,nil,LEGENDARY,80,"LG_80",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_80",OBTAIN,TRANSMOG,49623)
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_STR_90",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_STR_90",NOOBTAIN,TRANSMOG,102249)
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_STR_90",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_STR_90",NOOBTAIN,TRANSMOG,102250)
	
	-- Raid Tier Sets
	set = AddSet(60200,nil,RAID,18,"DK_TR_18",DEATHKNIGHT,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128134,128123,128127,128139,128135,128032)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124332,124344,124317,124327,124348,124338,124321)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124332,566),T18(124344,566),T18(124317,566),T18(124327,566),T18(124348,566),T18(124338,566),T18(124321,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124332,567),T18(124344,567),T18(124317,567),T18(124327,567),T18(124348,567),T18(124338,567),T18(124321,567))
	
	set = AddSet(60000,nil,RAID,17,"DK_TR_17",DEATHKNIGHT,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120396,120395,120393,120392,120391,120394)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115539,115536,115537,115538,115535)	-- No Bonus
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115539,566),T17(115536,566),T17(115537,566),T17(115538,566),T17(115535,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115539,567),T17(115536,567),T17(115537,567),T17(115538,567),T17(115535,567))
	
	set = AddSet(50400,nil,RAID,16,"DK_TR_MELEE_16",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99057,99059,99066,99067,99058)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99571,99639,99608,99609,99572)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99194,99187,99192,99193,99186)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99337,99339,99335,99336,99338)
	
	set = AddSet(50400,nil,RAID,16,"DK_TR_TANK_16",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99049,99040,99060,99048,99039)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99605,99652,99640,99604,99564)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99190,99179,99188,99189,99191)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99323,99325,99330,99331,99324)

	set = AddSet(50400,nil,RAID,15,"DK_TR_TANK_15",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95827,95829,95825,95826,95828)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95227,95229,95225,95226,95228)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96571,96573,96569,96570,96572)

	set = AddSet(50400,nil,RAID,15,"DK_TR_MELEE_15",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95832,95834,95830,95831,95833)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95232,95234,95230,95231,95233)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96576,96578,96574,96575,96577)
	
	set = AddSet(50400,nil,RAID,14,"DK_TR_TANK_14",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86656,86654,86658,86657,86655)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85316,85314,85318,85317,85315)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,86920,86922,86918,86919,86921)
	
	set = AddSet(50400,nil,RAID,14,"DK_TR_MELEE_14",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86676,86674,86678,86677,86675)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85336,85334,85338,85337,85335)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,86915,86917,86913,86914,86916)

	set = AddSet(50400,nil,RAID,13,"DK_TR_TANK_13",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78792,78846,78758,78773,78811)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,77010,77012,77008,77009,77011)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78697,78751,78663,78678,78716)

	set = AddSet(50400,nil,RAID,13,"DK_TR_MELEE_13",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78782,78831,78754,78765,78802)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76976,76978,76974,76975,76977)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78687,78736,78659,78670,78707)
	
	set = AddSet(50400,nil,RAID,12,"DK_TR_TANK_12",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,70954,70951,70955,70953,70952)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71483,71485,71481,71482,71484)

	set = AddSet(50400,nil,RAID,12,"DK_TR_MELEE_12",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71060,71062,71058,71059,71061)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71478,71480,71476,71477,71479)
	
	set = AddSet(50400,nil,RAID,11,"DK_TR_TANK_11",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",60351,60353,60349,60350,60352)
				AddVariant(50400,nil,RAID,set,"HEROIC",65186,65188,65184,65185,65187)

	set = AddSet(50400,nil,RAID,11,"DK_TR_MELEE_11",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60341,60343,60339,60340,60342)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65181,65183,65179,65180,65182)
	
	set = AddSet(50400,nil,RAID,10,"DK_TR_TANK_10",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50855,50853,50857,50856,50854)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51133,51130,51134,51132,51131)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51306,51309,51305,51307,51308)

	set = AddSet(50400,nil,RAID,10,"DK_TR_MELEE_10",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50096,50098,50094,50095,50097)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51127,51125,51129,51128,51126)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51312,51314,51310,51311,51313)
	
	set = AddSet(50400,nil,RAID,9,"DK_TR_TANK_A_09",DEATHKNIGHT,TANK,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48529,48535,48531,48537,48533)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48540,48542,48538,48539,48541)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48545,48543,48547,48546,48544)

	set = AddSet(50400,nil,RAID,9,"DK_TR_MELEE_A_09",DEATHKNIGHT,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48472,48478,48474,48480,48476)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48483,48485,48481,48482,48484)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48488,48486,48490,48489,48487)

	set = AddSet(50400,nil,RAID,9,"DK_TR_TANK_H_09",DEATHKNIGHT,TANK,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48560,48562,48558,48559,48561)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48555,48553,48557,48556,48554)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48550,48552,48548,48549,48551)
	
	set = AddSet(50400,nil,RAID,9,"DK_TR_MELEE_H_09",DEATHKNIGHT,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48503,48505,48501,48502,48504)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48498,48496,48500,48499,48497)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48493,48495,48491,48492,48494)
	
	set = AddSet(50400,nil,RAID,8,"DK_TR_TANK_08",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45336,45339,45335,45337,45338)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46120,46122,46118,46119,46121)

	set = AddSet(50400,nil,RAID,8,"DK_TR_MELEE_08",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45342,45344,45340,45341,45343)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46115,46117,46111,46113,46116)

	set = AddSet(50400,nil,RAID,7,"DK_TR_TANK_07",DEATHKNIGHT,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39625,39627,39623,39624,39626)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40565,40568,40559,40563,40567)

	set = AddSet(50400,nil,RAID,7,"DK_TR_MELEE_07",DEATHKNIGHT,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39619,39621,39617,39618,39620)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40554,40557,40550,40552,40556)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"DK_CD_90",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"DK_CD_90",NOOBTAIN,TRANSMOG,90053,90055,90051,90056,90052,90049,90054,90050)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,1,"DG_PLATE_03",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_PLATE_03",OBTAIN,TRANSMOG,28225,27771,28403,27497,27870)
				
	-- PvP
	set = AddSet(60200,nil,PVP,18,"DK_PVP_18",DEATHKNIGHT,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126186,126188,126184,126185,126187)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126029,126031,126027,126028,126030)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125827,125829,125825,125826,125828)
				
	set = AddSet(60200,nil,PVP,18,"DK_PVP_18",DEATHKNIGHT,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126663,126665,126661,126662,126664)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126506,126508,126504,126505,126507)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126306,126308,126304,126305,126307)
				
	set = AddSet(60200,nil,PVP,17,"DK_PVP_17",DEATHKNIGHT,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125072,125074,125070,125071,125073)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,124915,124917,124913,124914,124916)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124713,124715,124711,124712,124714)
				
	set = AddSet(60200,nil,PVP,17,"DK_PVP_17",DEATHKNIGHT,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125549,125551,125547,125548,125550)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125392,125394,125390,125391,125393)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125192,125194,125190,125191,125193)
				
	set = AddSet(50400,nil,PVP,16,"DK_PVP_16",DEATHKNIGHT,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115199,115201,115197,115198,115200)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115051,115053,115049,115050,115052)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115631,115633,115629,115630,115632)
				
	set = AddSet(50400,nil,PVP,16,"DK_PVP_16",DEATHKNIGHT,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,119976,119978,119974,119975,119977)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119841,119843,119839,119840,119842)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111104,111106,111102,111103,111105)
				
	set = AddSet(50400,nil,PVP,15,"DK_PVP_MELEE_15",DEATHKNIGHT,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102713,102652,102676,102650,102651)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103006,103008,103004,103005,103073,103007,103076)
				
	set = AddSet(50400,nil,PVP,15,"DK_PVP_MELEE_15",DEATHKNIGHT,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103379,103377,103378,103376,103380)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103006,103008,103004,103005,103073,103007,103076)
				
	set = AddSet(50400,nil,PVP,14,"DK_PVP_MELEE_14",DEATHKNIGHT,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100247,100251,100243,100245,100249)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100248,100252,100244,100246,100250)
				
	set = AddSet(50400,nil,PVP,14,"DK_PVP_MELEE_14",DEATHKNIGHT,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100659,100596,100622,100594,100595)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100248,100252,100244,100246,100250)
				
end

local function AddDruidSets()
	local set = 0
	
	-- Legendaries
	set = AddSet(60200,nil,LEGENDARY,100,"LG_CASTER_INT_100",DRUID,CASTER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_CASTER_INT_100",OBTAIN,NOTRANSMOG,124638)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_MELEE_AGI_100",DRUID,MELEE,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_MELEE_AGI_100",OBTAIN,NOTRANSMOG,124636)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_HEALER_INT_100",DRUID,HEALER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_HEALER_INT_100",OBTAIN,NOTRANSMOG,124635)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_TANK_100",DRUID,TANK,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_TANK_100",OBTAIN,NOTRANSMOG,124637)
				
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",DRUID,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",NOOBTAIN,TRANSMOG,102246)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",DRUID,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",NOOBTAIN,TRANSMOG,102248)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_AGI_90",DRUID,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_AGI_90",NOOBTAIN,TRANSMOG,102245)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",DRUID,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",NOOBTAIN,TRANSMOG,102247)
				
	set = AddSet(50400,nil,LEGENDARY,85,"LG_85",DRUID,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_85",OBTAIN,TRANSMOG,71086)
				
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",DRUID,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",OBTAIN,TRANSMOG,46017)
				
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",DRUID,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",OBTAIN,TRANSMOG,17182)
	
	-- Raid Tier Sets
	set = AddSet(60200,nil,RAID,18,"DR_TR_18",DRUID,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128130,128121,128125,128137,128131,128054)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124261,124272,124246,124255,124275,124267,124249)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124261,566),T18(124272,566),T18(124246,566),T18(124255,566),T18(124275,566),T18(124267,566),T18(124249,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124261,567),T18(124272,567),T18(124246,567),T18(124255,567),T18(124275,567),T18(124267,567),T18(124249,567))
	
	set = AddSet(60000,nil,RAID,17,"DR_TR_17",DRUID,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120382,120381,120380,120384,120379,120383)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115542,115544,115540,115541,115543)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115542,566),T17(115544,566),T17(115540,566),T17(115541,566),T17(115543,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115542,567),T17(115544,567),T17(115540,567),T17(115541,567),T17(115543,567))
	
	set = AddSet(50400,nil,RAID,16,"DR_TR_CASTER_16",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,98995,98998,98997,98994,98996)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99618,99621,99620,99617,99619)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99175,99169,99177,99174,99176)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99433,99428,99427,99432,99434)

	set = AddSet(50400,nil,RAID,16,"DR_TR_MELEE_16",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99043,99022,99041,99042,99044)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99599,99589,99632,99633,99600)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99182,99184,99180,99181,99183)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99328,99322,99326,99327,99329)

	set = AddSet(50400,nil,RAID,16,"DR_TR_TANK_16",DRUID,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99001,98978,98999,99000,98981)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99624,99664,99622,99623,99610)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99164,99166,99170,99163,99165)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99421,99423,99419,99420,99422)

	set = AddSet(50400,nil,RAID,16,"DR_TR_HEALER_16",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99013,99016,99015,99012,99014)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99638,99583,99582,99637,99581)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99178,99173,99172,99185,99171)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99436,99431,99430,99435,99429)

	set = AddSet(50400,nil,RAID,15,"DR_TR_CASTER_15",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95846,95849,95848,95845,95847)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95246,95249,95248,95245,95247)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96590,96593,96592,96589,96591)

	set = AddSet(50400,nil,RAID,15,"DR_TR_MELEE_15",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95837,95839,95835,95836,95838)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95237,95239,95235,95236,95238)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96581,96583,96579,96580,96582)

	set = AddSet(50400,nil,RAID,15,"DR_TR_TANK_15",DRUID,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95852,95854,95850,95851,95853)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95252,95254,95250,95251,95253)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96596,96598,96594,96595,96597)

	set = AddSet(50400,nil,RAID,15,"DR_TR_HEALER_15",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95841,95844,95843,95840,95842)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95241,95244,95243,95240,95242)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96585,96588,96587,96584,96586)

	set = AddSet(50400,nil,RAID,14,"DR_TR_CASTER_14",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86647,86644,86645,86648,86696)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85307,85304,85305,85308,85356)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,86934,86937,86936,86933,86930)
	
	set = AddSet(50400,nil,RAID,14,"DR_TR_MELEE_14",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86651,86649,86653,86652,86650)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85311,85309,85313,85312,85310)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,86925,86927,86923,86924,86926)
	
	set = AddSet(50400,nil,RAID,14,"DR_TR_TANK_14",DRUID,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86721,86723,86719,86720,86722)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85381,85383,85379,85380,85382)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,86940,86942,86938,86939,86941)
	
	set = AddSet(50400,nil,RAID,14,"DR_TR_HEALER_14",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86697,86694,86695,86698,86646)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85357,85354,85355,85358,85306)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,86929,86932,86931,86928,86935)
	
	set = AddSet(50400,nil,RAID,13,"DR_TR_CASTER_13",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78791,78839,78757,78771,78809)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,77019,77022,77021,77018,77020)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78696,78744,78662,78676,78714)

	set = AddSet(50400,nil,RAID,13,"DR_TR_MELEE_13",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78789,78838,78760,78779,78808)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,77015,77017,77013,77014,77016)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78694,78743,78665,78684,78713)

	set = AddSet(50400,nil,RAID,13,"DR_TR_HEALER_13",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78785,78835,78755,78775,78805)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76750,76753,76752,76749,76751)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78690,78740,78660,78680,78710)
	
	set = AddSet(50400,nil,RAID,12,"DR_TR_CASTER_12",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71108,71111,71110,71107,71109)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71497,71500,71499,71496,71498)

	set = AddSet(50400,nil,RAID,12,"DR_TR_MELEE_12",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71098,71101,71100,71097,71099)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71488,71490,71486,71487,71489)

	set = AddSet(50400,nil,RAID,12,"DR_TR_HEALER_12",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71103,71106,71105,71102,71104)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71492,71495,71494,71491,71493)
	
	set = AddSet(50400,nil,RAID,11,"DR_TR_CASTER_11",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60282,60284,60281,60285,60283)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65200,65203,65202,65199,65201)

	set = AddSet(50400,nil,RAID,11,"DR_TR_MELEE_11",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60286,60289,60287,60290,60288)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65190,65193,65192,65189,65191)

	set = AddSet(50400,nil,RAID,11,"DR_TR_HEALER_11",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60277,60279,60276,60280,60278)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65195,65198,65197,65194,65196)

	set = AddSet(50400,nil,RAID,10,"DR_TR_CASTER_10",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50821,50819,50823,50822,50820)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51149,51147,51145,51148,51146)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51290,51292,51294,51291,51293)

	set = AddSet(50400,nil,RAID,10,"DR_TR_MELEE_10",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50826,50824,50828,50827,50825)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51143,51140,51141,51144,51142)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51296,51299,51298,51295,51297)

	set = AddSet(50400,nil,RAID,10,"DR_TR_HEALER_10",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50108,50113,50106,50107,50109)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51137,51135,51139,51138,51136)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51302,51304,51300,51301,51303)
	
	set = AddSet(50400,nil,RAID,9,"DR_TR_CASTER_A_09",DRUID,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48158,48161,48159,48162,48160)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48164,48167,48166,48163,48165)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48171,48168,48169,48172,48170)

	set = AddSet(50400,nil,RAID,9,"DR_TR_MELEE_A_09",DRUID,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48214,48217,48216,48213,48215)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48211,48208,48209,48212,48210)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48204,48207,48206,48203,48205)

	set = AddSet(50400,nil,RAID,9,"DR_TR_HEALER_A_09",DRUID,HEALER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48102,48131,48129,48132,48130)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48134,48137,48136,48133,48135)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48141,48138,48139,48142,48140)
	
	set = AddSet(50400,nil,RAID,9,"DR_TR_CASTER_H_09",DRUID,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48174,48177,48176,48173,48175)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48181,48178,48179,48182,48180)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48184,48187,48186,48183,48185)

	set = AddSet(50400,nil,RAID,9,"DR_TR_MELEE_H_09",DRUID,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48188,48191,48189,48192,48190)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48194,48197,48196,48193,48195)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48201,48198,48199,48202,48200)

	set = AddSet(50400,nil,RAID,9,"DR_TR_HEALER_H_09",DRUID,HEALER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48154,48157,48156,48153,48155)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48151,48148,48149,48152,48150)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48144,48147,48146,48143,48145)

	set = AddSet(50400,nil,RAID,8,"DR_TR_CASTER_08",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,46313,45352,45354,45351,45353)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46191,46196,46194,46189,46192)
	
	set = AddSet(50400,nil,RAID,8,"DR_TR_MELEE_08",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45356,45359,45358,45355,45357)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46161,46157,46159,46158,46160)

	set = AddSet(50400,nil,RAID,8,"DR_TR_HEALER_08",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45346,45349,45348,45345,45347)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46184,46187,46186,46183,46185)
	
	set = AddSet(50400,nil,RAID,7,"DR_TR_CASTER_07",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39545,39548,39547,39544,39546)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40467,40470,40469,40466,40468)
	
	set = AddSet(50400,nil,RAID,7,"DR_TR_MELEE_07",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39553,39556,39554,39557,39555)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40473,40494,40471,40472,40493)

	set = AddSet(50400,nil,RAID,7,"DR_TR_HEALER_07",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39531,39542,39538,39543,39539)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40461,40465,40463,40460,40462)
	
	set = AddSet(50400,nil,RAID,6,"DR_TR_MELEE_06",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_MELEE_06",OBTAIN,TRANSMOG,31039,31048,31042,34444,31034,34556,31044,34573)
				
	set = AddSet(50400,nil,RAID,6,"DR_TR_HEALER_06",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_HEALER_06",OBTAIN,TRANSMOG,31037,31047,31041,34445,31032,34554,31045,34571)
				
	set = AddSet(50400,nil,RAID,6,"DR_TR_CASTER_06",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_CASTER_06",OBTAIN,TRANSMOG,31040,31049,31043,34446,31035,34555,31046,34572)
	
	set = AddSet(50400,nil,RAID,5,"DR_TR_MELEE_05",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_MELEE_05",OBTAIN,TRANSMOG,30228,30230,30222,30223,30229)
	
	set = AddSet(50400,nil,RAID,5,"DR_TR_HEALER_05",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_HEALER_05",OBTAIN,TRANSMOG,30219,30221,30216,30217,30220)
	
	set = AddSet(50400,nil,RAID,5,"DR_TR_CASTER_05",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_CASTER_05",OBTAIN,TRANSMOG,30233,30235,30231,30232,30234)
	
	set = AddSet(50400,nil,RAID,4,"DR_TR_MELEE_04",DRUID,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_MELEE_04",OBTAIN,TRANSMOG,29098,29100,29096,29097,29099)
	
	set = AddSet(50400,nil,RAID,4,"DR_TR_HEALER_04",DRUID,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_HEALER_04",OBTAIN,TRANSMOG,29086,29089,29087,29090,29088)
	
	set = AddSet(50400,nil,RAID,4,"DR_TR_CASTER_04",DRUID,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_CASTER_04",OBTAIN,TRANSMOG,29093,29095,29091,29092,29094)
	
	set = AddSet(50400,nil,RAID,3,"DR_TR_03",DRUID,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_03",NOOBTAIN,TRANSMOG,22490,22491,22488,22495,22493,22494,22489,22492,23064)
	
	set = AddSet(50400,nil,RAID,2,"DR_TR_02",DRUID,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_02",OBTAIN,TRANSMOG,16900,16902,16897,16904,16899,16903,16901,16898)
	
	set = AddSet(50400,nil,RAID,1,"DR_TR_01",DRUID,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"DR_TR_01",OBTAIN,TRANSMOG,16834,16836,16833,16830,16831,16828,16835,16829)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"DR_CD_90",DRUID,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"DR_CD_90",NOOBTAIN,TRANSMOG,90062,90065,90064,90066,90061,90059,90063,90060)

	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"DR_DG_03",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DR_DG_03",OBTAIN,TRANSMOG,28348,27737,28202,27468,27873)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_LEATHER_03",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_LEATHER_03",OBTAIN,TRANSMOG,28224,27797,28264,27531,27837)
				
	set = AddSet(50400,nil,DUNGEON,22,"DR_DG_AQ_2",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DR_DG_AQ_2",OBTAIN,TRANSMOG,21353,21354,21357,21356,21355)
				
	set = AddSet(50400,nil,DUNGEON,21,"DR_DG_AQ_1",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DR_DG_AQ_1",OBTAIN,TRANSMOG,21407,21409,21408)
				
	set = AddSet(50400,nil,DUNGEON,20,"DR_DG_02",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78249,78247,78252,78253,78248,78246,78250,78251)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,22109,22112,22113,22108,22110,22106,22111,22107)
				
	set = AddSet(50400,nil,DUNGEON,10,"DR_DG_01",DRUID,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78238,78239,78242,78240,78241,78244,78245,78243)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16720,16718,16706,16714,16717,16716,16719,16715)

	-- PvP
	set = AddSet(60200,nil,PVP,18,"DR_PVP_18",DRUID,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126190,126193,126192,126189,126191)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126033,126036,126035,126032,126034)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125831,125834,125833,125830,125832)
				
	set = AddSet(60200,nil,PVP,18,"DR_PVP_18",DRUID,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126667,126670,126669,126666,126668)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126510,126513,126512,126509,126511)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126310,126313,126312,126309,126311)
				
	set = AddSet(60200,nil,PVP,17,"DR_PVP_17",DRUID,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125076,125079,125078,125075,125077)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,124919,124922,124921,124918,124920)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124717,124720,124719,124716,124718)
				
	set = AddSet(60200,nil,PVP,17,"DR_PVP_17",DRUID,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125553,125556,125555,125552,125554)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125396,125399,125398,125395,125397)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125196,125199,125198,125195,125197)
				
	set = AddSet(50400,nil,PVP,16,"DR_PVP_16",DRUID,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115203,115206,115205,115202,115204)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115055,115058,115057,115054,115056)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115635,115638,115637,115634,115636)
				
	set = AddSet(50400,nil,PVP,16,"DR_PVP_16",DRUID,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,119980,119983,119982,119979,119981)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119845,119848,119847,119844,119846)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111108,111111,111110,111107,111109)
				
	set = AddSet(50400,nil,PVP,15,"DR_PVP_MELEE_15",DRUID,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102653,102741,102740,102739,102645)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103010,103013,103012,103009,103138,103011,103137)
				
	set = AddSet(50400,nil,PVP,15,"DR_PVP_HEALER_15",DRUID,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102776,102658,102721,102657,102761)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103017,103020,103019,103016,103014,103018,103015)
				
	set = AddSet(50400,nil,PVP,15,"DR_PVP_CASTER_15",DRUID,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102634,102700,102614,102696,102767)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103025,103028,103027,103024,103022,103026,103023)
				
	set = AddSet(50400,nil,PVP,15,"DR_PVP_MELEE_15",DRUID,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103381,103382,103383,103384,103385)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103012,103009,103010,103011,103013,103137,103138)
				
	set = AddSet(50400,nil,PVP,15,"DR_PVP_HEALER_15",DRUID,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103389,103390,103391,103392,103393)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103017,103014,103015,103016,103018,103019,103020)
				
	set = AddSet(50400,nil,PVP,15,"DR_PVP_CASTER_15",DRUID,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103398,103399,103400,103401,103402)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103025,102022,103023,103024,103026,103027,103028)
				
	set = AddSet(50400,nil,PVP,14,"DR_PVP_MELEE_14",DRUID,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100255,100261,100259,100253,100257)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100256,100262,100260,100254,100258)
				
	set = AddSet(50400,nil,PVP,14,"DR_PVP_HEALER_14",DRUID,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100270,100276,100274,100268,100272)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100271,100277,100275,100269,100273)
				
	set = AddSet(50400,nil,PVP,14,"DR_PVP_CASTER_14",DRUID,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100287,100293,100291,100285,100289)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100288,100294,100292,100286,100290)
				
	set = AddSet(50400,nil,PVP,14,"DR_PVP_MELEE_14",DRUID,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100597,100687,100686,100685,100598)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100256,100262,100260,100254,100258)
				
	set = AddSet(50400,nil,PVP,14,"DR_PVP_HEALER_14",DRUID,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100722,100602,100667,100601,100707)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100271,100277,100275,100269,100273)
				
	set = AddSet(50400,nil,PVP,14,"DR_PVP_CASTER_14",DRUID,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100577,100646,100557,100642,100713)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100288,100294,100292,100286,100290)
				
end



local function AddHunterSets()
	local set = ""
	
	-- Legendary
	set = AddSet(60200,nil,LEGENDARY,100,"LG_MELEE_AGI_100",HUNTER,MELEE,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_MELEE_AGI_100",OBTAIN,NOTRANSMOG,124636)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",NOOBTAIN,TRANSMOG,102248)
				
	set = AddSet(50400,nil,LEGENDARY,70,"LG_RANGED_70",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_RANGED_70",OBTAIN,TRANSMOG,34334)

	-- Raid
	set = AddSet(60200,nil,RAID,18,"HU_TR_18",HUNTER,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128132,128122,128126,128138,128133,128080)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124296,124307,124284,124292,124310,124301,124285)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124296,566),T18(124307,566),T18(124284,566),T18(124292,566),T18(124310,566),T18(124301,566),T18(124285,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124296,567),T18(124307,567),T18(124284,567),T18(124292,567),T18(124310,567),T18(124301,567),T18(124285,567))
	
	set = AddSet(60000,nil,RAID,17,"HU_TR_17",HUNTER,RANGED,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120390,120388,120389,120386,120385,120387)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115545,115547,115548,115549,115546)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115545,566),T17(115547,566),T17(115548,566),T17(115549,566),T17(115546,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115545,567),T17(115547,567),T17(115548,567),T17(115549,567),T17(115546,567))
				
	set = AddSet(50400,nil,RAID,16,"HU_TR_RANGED_16",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99080,99082,99085,99086,99081)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99660,99574,99577,99578,99573)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99157,99159,99167,99168,99158)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99402,99404,99405,99406,99403)

	set = AddSet(50400,nil,RAID,15,"HU_TR_RANGED_15",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95884,95886,95882,95883,95885)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95257,95259,95255,95256,95258)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96628,96630,96626,96627,96629)

	set = AddSet(50400,nil,RAID,14,"HU_TR_RANGED_14",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86636,86634,86638,86637,86635)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85296,85294,85298,85297,85295)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87004,87006,87002,87003,87005)

	set = AddSet(50400,nil,RAID,13,"HU_TR_RANGED_13",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78793,78832,78756,78769,78804)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,77030,77032,77028,77029,77031)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78698,78737,78661,78674,78709)

	set = AddSet(50400,nil,RAID,12,"HU_TR_RANGED_12",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71051,71053,71054,71050,71052)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71503,71505,71501,71502,71504)

	set = AddSet(50400,nil,RAID,11,"HU_TR_RANGED_11",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60303,60306,60304,60307,60305)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65206,65208,65204,65205,65207)

	set = AddSet(50400,nil,RAID,10,"HU_TR_RANGED_10",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50115,50117,50118,50114,50116)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51153,51151,51150,51154,51152)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51286,51288,51289,51285,51287)

	set = AddSet(50400,nil,RAID,9,"HU_TR_RANGED_A_09",HUNTER,RANGED,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48250,48253,48251,48254,48252)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48257,48259,48255,48256,48258)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48262,48260,48264,48263,48261)
				
	set = AddSet(50400,nil,RAID,9,"HU_TR_RANGED_H_09",HUNTER,RANGED,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48277,48279,48275,48276,48278)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48272,48270,48274,48273,48271)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48267,48269,48265,48266,48268)

	set = AddSet(50400,nil,RAID,8,"HU_TR_RANGED_08",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45361,45363,45364,45360,45362)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46143,46145,46141,46142,46144)

	set = AddSet(50400,nil,RAID,7,"HU_TR_RANGED_07",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39578,39581,39579,39582,39580)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40505,40507,40503,40504,40506)

	set = AddSet(50400,nil,RAID,6,"HU_TR_RANGED_06",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_RANGED_06",OBTAIN,TRANSMOG,31003,31006,31004,34443,31001,34549,31005,34570)

	set = AddSet(50400,nil,RAID,5,"HU_TR_RANGED_05",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_RANGED_05",OBTAIN,TRANSMOG,30141,30143,30139,30140,30142)

	set = AddSet(50400,nil,RAID,4,"HU_TR_RANGED_04",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_RANGED_04",OBTAIN,TRANSMOG,29081,29084,29082,29085,29083)

	set = AddSet(50400,nil,RAID,3,"HU_TR_03",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_03",NOOBTAIN,TRANSMOG,22438,22439,22436,22443,22441,22442,22437,22440,23067)

	set = AddSet(50400,nil,RAID,2,"HU_TR_02",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_02",OBTAIN,TRANSMOG,16939,16937,16942,16935,16940,16936,16938,16941)

	set = AddSet(50400,nil,RAID,1,"HU_TR_01",HUNTER,RANGED,ANY)
				AddVariant(50400,nil,RAID,set,"HU_TR_01",OBTAIN,TRANSMOG,16846,16848,16845,16850,16852,16851,16847,16849)
				
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"HU_CD_90",HUNTER,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"HU_CD_90",NOOBTAIN,TRANSMOG,90072,90074,90070,90075,90071,90068,90073,90069)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"HU_DG_03",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"HU_DG_03",OBTAIN,TRANSMOG,28275,27801,28228,27474,27874)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_MAIL_03",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_MAIL_03",OBTAIN,TRANSMOG,28192,27713,28401,27528,27936)
				
	set = AddSet(50400,nil,DUNGEON,22,"HU_DG_AQ_2",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"HU_DG_AQ_2",OBTAIN,TRANSMOG,21366,21367,21370,21368,21365)
				
	set = AddSet(50400,nil,DUNGEON,21,"HU_DG_AQ_1",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"HU_DG_AQ_1",OBTAIN,TRANSMOG,21401,21403,21402)
				
	set = AddSet(50400,nil,DUNGEON,20,"HU_DG_02",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78284,78281,78282,78283,78278,78285,78280,78279)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,22013,22016,22060,22011,22015,22010,22017,22061)
				
	set = AddSet(50400,nil,DUNGEON,10,"HU_DG_01",HUNTER,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78275,78273,78270,78277,78271,78274,78276,78272)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16677,16679,16674,16681,16676,16680,16678,16675)
				
	-- PvP
	set = AddSet(60200,nil,PVP,18,"HU_PVP_18",HUNTER,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126196,126198,126194,126195,126197)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126039,126041,126037,126038,126040)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125837,125839,125835,125836,125838)
				
	set = AddSet(60200,nil,PVP,18,"HU_PVP_18",HUNTER,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126673,126675,126671,126672,126674)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126516,126518,126514,126515,126517)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126316,126318,126314,126315,126317)
				
	set = AddSet(60200,nil,PVP,17,"HU_PVP_17",HUNTER,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125082,125084,125080,125081,125083)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,124925,124927,124923,124924,124926)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124723,124725,124721,124722,124724)
				
	set = AddSet(60200,nil,PVP,17,"HU_PVP_17",HUNTER,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125559,125561,125557,125558,125560)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125402,125404,125400,125401,125403)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125202,125204,125200,125201,125203)
				
	set = AddSet(50400,nil,PVP,16,"HU_PVP_16",HUNTER,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115209,115211,115207,115208,115210)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115061,115063,115059,115060,115062)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115641,115643,115639,115640,115642)
				
	set = AddSet(50400,nil,PVP,16,"HU_PVP_16",HUNTER,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,119986,119988,119984,119985,119987)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119851,119853,119849,119850,119852)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111114,111116,111112,111113,111115)
				
	set = AddSet(50400,nil,PVP,15,"HU_PVP_RANGED_15",HUNTER,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102670,102690,102734,102737,102689)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103038,103033,103035,103037,103039,103040,103041)
				
	set = AddSet(50400,nil,PVP,15,"HU_PVP_RANGED_15",HUNTER,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103416,103417,103418,103419,103420)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103038,103033,103035,103037,103039,103040,103041)
				
	set = AddSet(50400,nil,PVP,14,"HU_PVP_RANGED_14",HUNTER,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100322,100326,100318,100320,100324)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100323,100327,100319,100321,100325)
				
	set = AddSet(50400,nil,PVP,14,"HU_PVP_RANGED_14",HUNTER,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100636,100680,100635,100683,100614)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100323,100327,100319,100321,100325)
	
end

local function AddMageSets()
	local set = ""
	
  -- Legendaries
	set = AddSet(60200,nil,LEGENDARY,100,"LG_CASTER_INT_100",MAGE,CASTER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_CASTER_INT_100",OBTAIN,NOTRANSMOG,124638)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",MAGE,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",NOOBTAIN,TRANSMOG,102246)
				
	set = AddSet(50400,nil,LEGENDARY,85,"LG_85",MAGE,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_85",OBTAIN,TRANSMOG,71086)
	
	-- Raid
	set = AddSet(60200,nil,RAID,18,"MA_TR_18",MAGE,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128128,128120,128124,128136,128129,128052)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124160,124177,124171,124154,124165,124148)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124160,566),T18(124177,566),T18(124171,566),T18(124154,566),T18(124165,566),T18(124148,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124160,567),T18(124177,567),T18(124171,567),T18(124154,567),T18(124165,567),T18(124148,567))
	
	set = AddSet(60000,nil,RAID,17,"MA_TR_17",MAGE,CASTER,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120373,120376,120375,120374,120377,120378)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115553,115551,115550,115552,115554)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115553,566),T17(115551,566),T17(115550,566),T17(115552,566),T17(115554,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115553,567),T17(115551,567),T17(115550,567),T17(115552,567),T17(115554,567))
				
	set = AddSet(50400,nil,RAID,16,"MA_TR_CASTER_16",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99084,99079,99078,99083,99077)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99576,99659,99658,99575,99657)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99161,99153,99152,99160,99162)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99398,99401,99400,99397,99399)

	set = AddSet(50400,nil,RAID,15,"MA_TR_CASTER_15",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95891,95894,95893,95890,95892)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95261,95264,95263,95260,95262)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96635,96638,96637,96634,96636)

	set = AddSet(50400,nil,RAID,14,"MA_TR_CASTER_14",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86717,86714,86715,86718,86716)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85377,85374,85375,85378,85376)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87008,87011,87010,87007,87009)

	set = AddSet(50400,nil,RAID,13,"MA_TR_CASTER_13",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78796,78843,78824,78766,78815)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76213,76216,76215,76212,76214)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78701,78748,78729,78671,78720)

	set = AddSet(50400,nil,RAID,12,"MA_TR_CASTER_12",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71287,71290,71289,71286,71288)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71508,71511,71510,71507,71509)

	set = AddSet(50400,nil,RAID,11,"MA_TR_CASTER_11",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60243,60246,60244,60247,60245)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65210,65213,65212,65209,65211)

	set = AddSet(50400,nil,RAID,10,"MA_TR_CASTER_10",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50276,50279,50278,50275,50277)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51158,51155,51156,51159,51157)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51281,51284,51283,51280,51282)

	set = AddSet(50400,nil,RAID,9,"DR_TR_CASTER_A_09",MAGE,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,47748,47751,47749,47752,47750)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,47754,47757,47756,47753,47755)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,47761,47758,47759,47762,47760)
				
	set = AddSet(50400,nil,RAID,9,"MA_TR_CASTER_H_09",MAGE,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,47774,47777,47776,47773,47775)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,47771,47768,47769,47772,47770)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,47764,47767,47766,47763,47765)

	set = AddSet(50400,nil,RAID,8,"MA_TR_CASTER_08",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45365,45369,45368,46131,45367)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46129,46134,46130,46132,46133)

	set = AddSet(50400,nil,RAID,7,"MA_TR_CASTER_07",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39491,39494,39492,39495,39493)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40416,40419,40418,40415,40417)

	set = AddSet(50400,nil,RAID,6,"MA_TR_CASTER_06",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_CASTER_06",OBTAIN,TRANSMOG,31056,31059,31057,34447,31055,34557,31058,34574)

	set = AddSet(50400,nil,RAID,5,"MA_TR_CASTER_05",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_CASTER_05",OBTAIN,TRANSMOG,30206,30210,30196,30205,30207)

	set = AddSet(50400,nil,RAID,4,"MA_TR_CASTER_04",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_CASTER_04",OBTAIN,TRANSMOG,29076,29079,29077,29080,29078)

	set = AddSet(50400,nil,RAID,3,"MA_TR_03",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_03",NOOBTAIN,TRANSMOG,22498,22499,22496,22503,22501,22502,22497,22500,23062)

	set = AddSet(50400,nil,RAID,2,"MA_TR_02",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_02",OBTAIN,TRANSMOG,16914,16917,16916,16918,16913,16818,16915,16912)

	set = AddSet(50400,nil,RAID,1,"MA_TR_01",MAGE,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"MA_TR_01",OBTAIN,TRANSMOG,16795,16797,16798,16799,16801,16802,16796,16800)

	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"MA_CD_90",MAGE,CASTER,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"MA_CD_90",NOOBTAIN,TRANSMOG,90082,90085,90084,90086,90081,90079,90083,90080)

	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"MA_DG_03",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"MA_DG_03",OBTAIN,TRANSMOG,28278,27738,28229,27508,27838)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_CLOTH_03",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_CLOTH_03",OBTAIN,TRANSMOG,28193,27796,28191,27465,27907)
				
	set = AddSet(50400,nil,DUNGEON,22,"MA_DG_AQ_2",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"MA_DG_AQ_2",OBTAIN,TRANSMOG,21347,21345,21343,21346,21344)
				
	set = AddSet(50400,nil,DUNGEON,21,"MA_DG_AQ_1",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"MA_DG_AQ_1",OBTAIN,TRANSMOG,21413,21415,21414)
				
	set = AddSet(50400,nil,DUNGEON,20,"MA_DG_02",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78198,78201,78200,78203,78197,78202,78199,78196)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,22065,22068,22069,22063,22066,22062,22067,22064)
				
	set = AddSet(50400,nil,DUNGEON,10,"MA_DG_01",MAGE,CASTER,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78188,78191,78190,78193,78187,78192,78189,78186)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16686,16689,16688,16683,16684,16685,16687,16682)
					
	-- PvP
	set = AddSet(60200,nil,PVP,18,"MA_PVP_18",MAGE,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126211,126214,126213,126210,126212)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126078,126081,126080,126077,126079)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125884,125887,125886,125883,125885)
				
	set = AddSet(60200,nil,PVP,18,"MA_PVP_18",MAGE,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126688,126691,126690,126687,126689)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126555,126558,126557,126554,126556)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126363,126366,126365,126362,126364)
				
	set = AddSet(60200,nil,PVP,17,"MA_PVP_17",MAGE,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125097,125100,125099,125096,125098)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,124964,124967,124966,124963,124965)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124770,124773,124772,124769,124771)
				
	set = AddSet(60200,nil,PVP,17,"MA_PVP_17",MAGE,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125574,125577,125576,125573,125575)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125441,125444,125443,125440,125442)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125249,125252,125251,125248,125250)
				
	set = AddSet(50400,nil,PVP,16,"MA_PVP_16",MAGE,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115221,115224,115223,115220,115222)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115091,115094,115093,115090,115092)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115678,115681,115680,115677,115679)
				
	set = AddSet(50400,nil,PVP,16,"MA_PVP_16",MAGE,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,119998,120001,120000,119997,119999)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119874,119877,119876,119873,119875)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111151,111154,111153,111150,111152)
				
	set = AddSet(50400,nil,PVP,15,"MA_PVP_CASTER_15",MAGE,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102648,102673,102715,102735,102667)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103043,102991,102994,103042,103044,103045,103046)
				
	set = AddSet(50400,nil,PVP,15,"MA_PVP_CASTER_15",MAGE,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103421,103422,103423,103424,103425)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103043,102991,102994,103042,103044,103045,103046)
				
	set = AddSet(50400,nil,PVP,14,"MA_PVP_CASTER_14",MAGE,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100330,100336,100334,100328,100332)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100331,100337,100335,100329,100333)
				
	set = AddSet(50400,nil,PVP,14,"MA_PVP_CASTER_14",MAGE,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100611,100619,100661,100681,100592)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100331,100337,100335,100329,100333)
				
end


local function AddMonkSets()
	local set = ""
	
	-- Legendary
	set = AddSet(60200,nil,LEGENDARY,100,"LG_MELEE_AGI_100",MONK,MELEE,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_MELEE_AGI_100",OBTAIN,NOTRANSMOG,124636)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_HEALER_INT_100",MONK,HEALER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_HEALER_INT_100",OBTAIN,NOTRANSMOG,124635)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_TANK_100",MONK,TANK,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_TANK_100",OBTAIN,NOTRANSMOG,124637)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_AGI_90",MONK,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_AGI_90",NOOBTAIN,TRANSMOG,102245)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",MONK,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",NOOBTAIN,TRANSMOG,102248)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",MONK,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",NOOBTAIN,TRANSMOG,102247)
				
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",MONK,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",OBTAIN,TRANSMOG,46017)
				
	set = AddSet(50400,nil,LEGENDARY,70,"LG_MELEE_70",MONK,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_70",OBTAIN,TRANSMOG,32837,32838)

	-- Raid
	set = AddSet(60200,nil,RAID,18,"MO_TR_18",MONK,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128130,128121,128125,128137,128131,128054)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124262,124273,124247,124256,124276,124268,124251)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124262,566),T18(124273,566),T18(124247,566),T18(124256,566),T18(124276,566),T18(124268,566),T18(124251,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124262,567),T18(124273,567),T18(124247,567),T18(124256,567),T18(124276,567),T18(124268,567),T18(124251,567))
	
	set = AddSet(60000,nil,RAID,17,"MO_TR_17",MONK,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120382,120381,120380,120384,120379,120383)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115556,115559,115558,115555,115557)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115556,566),T17(115559,566),T17(115558,566),T17(115555,566),T17(115557,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115556,567),T17(115559,567),T17(115558,567),T17(115555,567),T17(115557,567))

	set = AddSet(50400,nil,RAID,16,"MO_TR_TANK_16",MONK,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99065,99051,99063,99064,99050)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99607,99565,99643,99644,99606)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99142,99144,99140,99141,99143)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99384,99386,99382,99383,99385)

	set = AddSet(50400,nil,RAID,16,"MO_TR_MELEE_16",MONK,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99073,99075,99071,99072,99074)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99653,99655,99555,99556,99654)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99156,99146,99154,99155,99145)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99393,99395,99396,99392,99394)

	set = AddSet(50400,nil,RAID,16,"MO_TR_HEALER_16",MONK,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99069,99062,99061,99068,99070)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99553,99642,99641,99552,99554)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99148,99151,99150,99147,99149)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99389,99381,99391,99388,99390)

	set = AddSet(50400,nil,RAID,15,"MO_TR_TANK_15",MONK,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95907,95909,95905,95906,95908)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95277,95279,95275,95276,95278)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96651,96653,96649,96650,96652)

	set = AddSet(50400,nil,RAID,15,"MO_TR_MELEE_15",MONK,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95897,95899,95895,95896,95898)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95267,95269,95265,95266,95268)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96641,96643,96639,96640,96642)

	set = AddSet(50400,nil,RAID,15,"MO_TR_HEALER_15",MONK,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95901,95904,95903,95900,95902)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95271,95274,95273,95270,95272)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96645,96648,96647,96644,96646)
	
	set = AddSet(50400,nil,RAID,14,"MO_TR_TANK_14",MONK,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86726,86724,86728,86727,86725)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85386,85384,85388,85387,85385)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87096,87098,87094,87095,87097)

	set = AddSet(50400,nil,RAID,14,"MO_TR_MELEE_14",MONK,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86730,86733,86732,86729,86731)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85390,85393,85392,85389,85391)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87090,87093,87092,87089,87091)

	set = AddSet(50400,nil,RAID,14,"MO_TR_HEALER_14",MONK,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86736,86738,86734,86735,86737)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85396,85398,85394,85395,85397)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87086,87088,87084,87085,87087)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"CHALLENGE",MONK,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"MO_CD_90",NOOBTAIN,TRANSMOG,90092,90094,90090,90095,90091,90088,90093,90089)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,1,"DG_LEATHER_03",MONK,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_LEATHER_03",OBTAIN,TRANSMOG,28224,27797,28264,27531,27837)

	-- PvP
	set = AddSet(60200,nil,PVP,18,"MO_PVP_18",MONK,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126219,126221,126222,126218,126220)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126094,126096,126097,126093,126095)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125908,125910,125911,125907,125909)
				
	set = AddSet(60200,nil,PVP,18,"MO_PVP_18",MONK,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126696,126698,126699,126695,126697)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126571,126573,126574,126570,126572)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126387,126389,126390,126386,126388)
				
	set = AddSet(60200,nil,PVP,17,"MO_PVP_17",MONK,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125105,125107,125108,125104,125106)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,124980,124982,124983,124979,124981)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124794,124796,124797,124793,124795)
				
	set = AddSet(60200,nil,PVP,17,"MO_PVP_17",MONK,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125582,125584,125585,125581,125583)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125457,125459,125460,125456,125458)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125273,125275,125276,125272,125274)
				
	set = AddSet(50400,nil,PVP,16,"MO_PVP_16",MONK,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115229,115231,115232,115228,115230)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115102,115104,115105,115101,115103)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115692,115694,115695,115691,115693)
				
	set = AddSet(50400,nil,PVP,16,"MO_PVP_16",MONK,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,120006,120008,120009,120005,120007)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119885,119887,119888,119884,119886)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111165,111167,111168,111164,111166)
				
	set = AddSet(50400,nil,PVP,15,"MO_PVP_HEALER_15",MONK,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102628,102777,102763,102627,102762)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103055,103057,103058,103054,103134,103056,103133)
				
	set = AddSet(50400,nil,PVP,15,"MO_PVP_MELEE_15",MONK,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102712,102626,102720,102675,102656)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103050,103052,103053,103049,103047,103051,103048)
				
	set = AddSet(50400,nil,PVP,15,"MO_PVP_HEALER_15",MONK,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103435,103437,103438,103434,103436)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103055,103057,103058,103054,103134,103056,103133)
				
	set = AddSet(50400,nil,PVP,15,"MO_PVP_MELEE_15",MONK,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103430,103432,103433,103429,103431)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103050,103052,103053,103049,103047,103051,103048)
				
	set = AddSet(50400,nil,PVP,14,"MO_PVP_HEALER_14",MONK,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100355,100359,100361,100353,100357)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100356,100360,100362,100354,100358)
				
	set = AddSet(50400,nil,PVP,14,"MO_PVP_MELEE_14",MONK,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100345,100349,100351,100343,100347)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100346,100350,100352,100344,100348)
				
	set = AddSet(50400,nil,PVP,14,"MO_PVP_HEALER_14",MONK,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100571,1007223,100709,100570,100708)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100356,100360,100362,100354,100358)
				
	set = AddSet(50400,nil,PVP,14,"MO_PVP_MELEE_14",MONK,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100658,100569,100666,1006221,100600)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100346,100350,100352,100344,100348)
				
end

local function AddPaladinSets()
	local set = ""
	
	-- Legendary
	set = AddSet(60200,nil,LEGENDARY,100,"LG_MELEE_STR_100",PALADIN,MELEE,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_MELEE_STR_100",OBTAIN,NOTRANSMOG,124634)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_TANK_100",PALADIN,TANK,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_TANK_100",OBTAIN,NOTRANSMOG,124637)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_HEALER_INT_100",PALADIN,HEALER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_HEALER_INT_100",OBTAIN,NOTRANSMOG,124635)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_STR_90",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_STR_90",NOOBTAIN,TRANSMOG,102249)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_STR_90",PALADIN,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_STR_90",NOOBTAIN,TRANSMOG,102250)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",NOOBTAIN,TRANSMOG,102247)
	
	set = AddSet(50400,nil,LEGENDARY,80,"LG_80",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_80",OBTAIN,TRANSMOG,49623)
	
	set = AddSet(50400,nil,LEGENDARY,80,"LG_80",PALADIN,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_80",OBTAIN,TRANSMOG,49623)
	
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",OBTAIN,TRANSMOG,46017)
	
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",OBTAIN,TRANSMOG,17182)
	
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",PALADIN,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",OBTAIN,TRANSMOG,17182)

	-- Raid
	set = AddSet(60200,nil,RAID,18,"PA_TR_18",PALADIN,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128134,128123,128127,128139,128135,128032)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124333,124345,124318,124328,124347,124339,124322)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124333,566),T18(124345,566),T18(124318,566),T18(124328,566),T18(124347,566),T18(124339,566),T18(124322,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124333,567),T18(124345,567),T18(124318,567),T18(124328,567),T18(124347,567),T18(124339,567),T18(124322,567))
	
	set = AddSet(60000,nil,RAID,17,"PA_TR_17",PALADIN,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120396,120395,120393,120392,120391,120394)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115568,115565,115566,115567,115569)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115568,566),T17(115565,566),T17(115566,566),T17(115567,566),T17(115569,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115568,567),T17(115565,567),T17(115566,567),T17(115567,567),T17(115569,567))

	set = AddSet(50400,nil,RAID,16,"PA_TR_HEALER_16",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,98979,99076,99003,98982,98980)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99665,99656,99626,99648,99666)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99135,99125,99133,99134,99124)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99376,99378,99374,99375,99377)
	
	set = AddSet(50400,nil,RAID,16,"PA_TR_TANK_16",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99029,99027,99031,99028,99026)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99596,99594,99598,99595,99593)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99128,99130,99126,99127,99129)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99370,99364,99368,99369,99371)

	set = AddSet(50400,nil,RAID,16,"PA_TR_MELEE_16",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,98985,98987,99052,99002,98986)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99651,99662,99566,99625,99661)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99138,99132,99136,99137,99139)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99379,99373,99387,99380,99372)

	set = AddSet(50400,nil,RAID,15,"PA_TR_HEALER_15",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95917,95919,95915,95916,95918)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95287,95289,95285,95286,95288)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96661,96663,96659,96660,96662)
	
	set = AddSet(50400,nil,RAID,15,"PA_TR_TANK_15",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95922,95924,95920,95921,95923)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95292,95294,95290,95291,95293)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96666,96668,96664,96665,96667)

	set = AddSet(50400,nil,RAID,15,"PA_TR_MELEE_15",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95912,95914,95910,95911,95913)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95282,95284,95280,95281,95283)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96656,96658,96654,96655,96657)
	
	set = AddSet(50400,nil,RAID,14,"PA_TR_HEALER_14",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86686,86684,86688,86687,86685)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85346,85344,85348,85347,85345)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87106,87108,87104,87105,87107)

	set = AddSet(50400,nil,RAID,14,"PA_TR_TANK_14",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86661,86659,86663,86662,86660)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85321,85319,85323,85322,85320)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87111,87113,87109,87110,87112)

	set = AddSet(50400,nil,RAID,14,"PA_TR_MELEE_14",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86681,86679,86683,86682,86680)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85341,85339,85343,85342,85340)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87101,87103,87099,87100,87102)	
	
	set = AddSet(50400,nil,RAID,13,"PA_TR_HEALER_13",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78787,78841,78821,78768,78812)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76767,76769,76765,76766,76768)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78692,78746,78726,78673,78717)

	set = AddSet(50400,nil,RAID,13,"PA_TR_TANK_13",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78790,78840,78827,78772,78810)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,77005,77007,77003,77004,77006)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78695,78745,78732,78677,78715)

	set = AddSet(50400,nil,RAID,13,"PA_TR_MELEE_13",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78788,78837,78822,78770,78807)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76876,76878,76874,76875,76877)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78693,78742,78727,78675,78712)
	
	set = AddSet(50400,nil,RAID,12,"PA_TR_HEALER_12",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71093,71095,71091,71092,71094)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71519,71521,71517,71518,71520)

	set = AddSet(50400,nil,RAID,12,"PA_TR_TANK_12",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,70948,70946,70950,70949,70947)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71524,71526,71522,71523,71525)

	set = AddSet(50400,nil,RAID,12,"PA_TR_MELEE_12",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71514,71516,71512,71513,71515)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71065,71067,71063,71064,71066)
	
	set = AddSet(50400,nil,RAID,11,"PA_TR_HEALER_11",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60359,60362,60360,60363,60361)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65221,65223,65219,65220,65222)

	set = AddSet(50400,nil,RAID,11,"PA_TR_TANK_11",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65226,65228,65224,65225,65227)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60356,60358,60354,60355,60357)

	set = AddSet(50400,nil,RAID,11,"PA_TR_MELEE_11",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60346,60348,60344,60345,60347)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65216,65218,65214,65215,65217)

	set = AddSet(50400,nil,RAID,10,"PA_TR_HEALER_10",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50867,50865,50869,50868,50866)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51167,51166,51165,51169,51168)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51272,51273,51274,51270,51271)
	
	set = AddSet(50400,nil,RAID,10,"PA_TR_TANK_10",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50862,50860,50864,50863,50861)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51173,51170,51174,51172,51171)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51266,51269,51265,51267,51268)

	set = AddSet(50400,nil,RAID,10,"PA_TR_MELEE_10",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50326,50324,50328,50327,50325)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51162,51160,51164,51163,51161)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51277,51279,51275,51276,51278)
	
	set = AddSet(50400,nil,RAID,9,"PA_TR_HEALER_A_09",PALADIN,HEALER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48564,48572,48566,48574,48568)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48577,48579,48575,48576,48578)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48582,48580,48584,48583,48581)

	set = AddSet(50400,nil,RAID,9,"PA_TR_TANK_A_09",PALADIN,TANK,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48634,48636,48632,48633,48635)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48639,48637,48641,48640,48638)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48644,48646,48642,48643,48645)

	set = AddSet(50400,nil,RAID,9,"PA_TR_MELEE_A_09",PALADIN,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48604,48606,48602,48603,48605)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48609,48611,48607,48608,48610)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48614,48612,48616,48615,48613)
	
	set = AddSet(50400,nil,RAID,9,"PA_TR_HEALER_H_09",PALADIN,HEALER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48597,48595,48599,48598,48596)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48592,48590,48594,48593,48591)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48587,48585,48589,48588,48586)

	set = AddSet(50400,nil,RAID,9,"PA_TR_TANK_H_09",PALADIN,TANK,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48654,48656,48652,48653,48655)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48659,48661,48657,48658,48660)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48649,48647,48651,48650,48648)

	set = AddSet(50400,nil,RAID,9,"PA_TR_MELEE_H_09",PALADIN,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48629,48627,48631,48630,48628)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48624,48622,48626,48625,48623)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48619,48621,48617,48618,48620)
	
	set = AddSet(50400,nil,RAID,8,"PA_TR_HEALER_08",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45372,45373,45374,45370,45371)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46180,46182,46178,46179,46181)

	set = AddSet(50400,nil,RAID,8,"PA_TR_TANK_08",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45382,45385,45381,45383,45384)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46175,46177,46173,46174,46176)

	set = AddSet(50400,nil,RAID,8,"PA_TR_MELEE_08",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45377,45380,45375,45376,45379)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46156,46152,46154,46155,46153)
	
	set = AddSet(50400,nil,RAID,7,"PA_TR_HEALER_07",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39628,39631,39629,39632,39630)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40571,40573,40569,40570,40572)

	set = AddSet(50400,nil,RAID,7,"PA_TR_TANK_07",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39640,39642,39638,39639,39641)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40581,40584,40579,40580,40583)

	set = AddSet(50400,nil,RAID,7,"PA_TR_MELEE_07",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39635,39637,39633,39634,39636)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40576,40578,40574,40575,40577)

	set = AddSet(50400,nil,RAID,6,"PA_TR_HEALER_06",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_HEALER_06",OBTAIN,TRANSMOG,30988,30996,30992,34432,30983,34487,30994,34559)
	
	set = AddSet(50400,nil,RAID,6,"PA_TR_TANK_06",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_TANK_06",OBTAIN,TRANSMOG,30987,30998,30991,34433,30985,34488,30995,34560)
	
	set = AddSet(50400,nil,RAID,6,"PA_TR_MELEE_06",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_TANK_06",OBTAIN,TRANSMOG,30989,30997,30990,34431,30982,34485,30993,34561)

	set = AddSet(50400,nil,RAID,5,"PA_TR_HEALER_05",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_HEALER_05",OBTAIN,TRANSMOG,30136,30138,30134,30135,30137)

	set = AddSet(50400,nil,RAID,5,"PA_TR_TANK_05",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_TANK_05",OBTAIN,TRANSMOG,30125,30127,30123,30124,30126)

	set = AddSet(50400,nil,RAID,5,"PA_TR_MELEE_05",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_MELEE_05",OBTAIN,TRANSMOG,30131,30133,30129,30130,30132)

	set = AddSet(50400,nil,RAID,4,"PA_TR_HEALER_04",PALADIN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_HEALER_04",OBTAIN,TRANSMOG,29061,29064,29062,29065,29063)

	set = AddSet(50400,nil,RAID,4,"PA_TR_TANK_04",PALADIN,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_TANK_04",OBTAIN,TRANSMOG,29068,29070,29066,29067,29069)

	set = AddSet(50400,nil,RAID,4,"PA_TR_MELEE_04",PALADIN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_MELEE_04",OBTAIN,TRANSMOG,29073,29075,29071,29072,29074)
	
	set = AddSet(50400,nil,RAID,3,"PA_TR_03",PALADIN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_03",NOOBTAIN,TRANSMOG,22428,22429,22425,22424,22426,22431,22427,22430,23066)
	
	set = AddSet(50400,nil,RAID,2,"PA_TR_02",PALADIN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PA_TR_02",OBTAIN,TRANSMOG,16955,16953,16958,16951,16956,16952,16954,16957)
	
	set = AddSet(50400,nil,RAID,1,"PA_TR_01",PALADIN,ANY,ANY,60)
				AddVariant(50400,nil,RAID,set,"PA_TR_01",OBTAIN,TRANSMOG,16854,16856,16853,16857,16860,16858,16855,16859)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,90,"PA_CD_90",PALADIN,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"PA_CD_90",NOOBTAIN,TRANSMOG,90100,90102,90098,90103,90099,90096,90101,90097)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"PA_DG_03",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PA_DG_03",OBTAIN,TRANSMOG,28285,27739,28203,27535,27839)
	
	set = AddSet(50400,nil,DUNGEON,31,"DG_PLATE_03",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_PLATE_03",OBTAIN,TRANSMOG,28225,27771,28403,27497,27870)
	
	set = AddSet(50400,nil,DUNGEON,22,"PA_DG_AQ_2",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PA_DG_AQ_2",OBTAIN,TRANSMOG,21387,21391,21389,21390,21388)
	
	set = AddSet(50400,nil,DUNGEON,21,"PA_DG_AQ_1",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PA_DG_AQ_1",OBTAIN,TRANSMOG,21395,21397,21396)
	
	set = AddSet(50400,nil,DUNGEON,20,"PA_DG_02",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78312,78316,78313,78317,78314,78311,78315,78310)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,22091,22093,22089,22088,22090,22086,22092,22087)
	
	set = AddSet(50400,nil,DUNGEON,10,"PA_DG_01",PALADIN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78307,78308,78306,78304,78303,78302,78305,78309)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16727,16729,16726,16722,16724,16723,16728,16725)

	-- PvP
	set = AddSet(60200,nil,PVP,18,"PA_PVP_18",PALADIN,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126225,126227,126223,126224,126226)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126100,126102,126098,126099,126101)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125914,125916,125912,125913,125915)
				
	set = AddSet(60200,nil,PVP,18,"PA_PVP_18",PALADIN,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126702,126704,126700,126701,126703)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126577,126579,126575,126576,126578)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126393,126395,126391,126392,126394)
				
	set = AddSet(60200,nil,PVP,17,"PA_PVP_17",PALADIN,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125111,125113,125109,125110,125112)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,124986,124988,124984,124985,124987)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124800,124802,124798,124799,124801)
				
	set = AddSet(60200,nil,PVP,17,"PA_PVP_17",PALADIN,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125588,125590,125586,125587,125589)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125463,125465,125461,125462,125464)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125279,125281,125277,125278,125280)
				
	set = AddSet(50400,nil,PVP,16,"PA_PVP_16",PALADIN,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115235,115237,115233,115234,115236)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115108,115110,115106,115107,115109)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115698,115700,115696,115697,115699)
				
	set = AddSet(50400,nil,PVP,16,"PA_PVP_16",PALADIN,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,120012,120014,120010,120011,120013)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119891,119893,119889,119890,119892)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111171,111173,111169,111170,111172)
				
	set = AddSet(50400,nil,PVP,15,"PA_PVP_HEALER_15",PALADIN,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102635,102697,102632,102722,102768)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103070,103072,103068,103069,103065,103071,103066)
				
	set = AddSet(50400,nil,PVP,15,"PA_PVP_MELEE_15",PALADIN,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102779,102744,102747,102630,102780)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103061,103063,103059,103060,103064,103062,103067)
				
	set = AddSet(50400,nil,PVP,15,"PA_PVP_HEALER_15",PALADIN,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103452,103454,103450,103451,103453)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103069,103065,103066,103068,103070,103071,103072)
				
	set = AddSet(50400,nil,PVP,15,"PA_PVP_MELEE_15",PALADIN,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103441,103443,103439,103440,103442)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103061,103063,103059,103060,103064,103062,103067)
				
	set = AddSet(50400,nil,PVP,14,"PA_PVP_HEALER_14",PALADIN,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100387,100391,100383,100385,100389)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100388,100392,100384,100386,100390)
				
	set = AddSet(50400,nil,PVP,14,"PA_PVP_MELEE_14",PALADIN,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100367,100371,100363,100365,100369)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100368,100372,100364,100366,100370)
				
	set = AddSet(50400,nil,PVP,14,"PA_PVP_HEALER_14",PALADIN,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100578,100643,100575,100668,100714)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100388,100392,100384,100386,100390)
				
	set = AddSet(50400,nil,PVP,14,"PA_PVP_MELEE_14",PALADIN,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100725,100690,100693,100573,100726)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100368,100372,100364,100366,100370)
	
end

local function AddPriestSets()
	local set = ""
	
	-- Legendary
	set = AddSet(60200,nil,LEGENDARY,100,"LG_CASTER_INT_100",PRIEST,CASTER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_CASTER_INT_100",OBTAIN,NOTRANSMOG,124638)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_HEALER_INT_100",PRIEST,HEALER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_HEALER_INT_100",OBTAIN,NOTRANSMOG,124635)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",NOOBTAIN,TRANSMOG,102247)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",NOOBTAIN,TRANSMOG,102246)
				
	set = AddSet(50400,nil,LEGENDARY,85,"LG_85",PRIEST,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_85",OBTAIN,TRANSMOG,71086)
				
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",PRIEST,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",OBTAIN,TRANSMOG,46017)

	-- Raid
	set = AddSet(60200,nil,RAID,18,"PR_TR_18",PRIEST,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128128,128120,128124,128136,128129,128052)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124161,124178,124172,124155,124180,124166,124149)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124161,566),T18(124178,566),T18(124172,566),T18(124155,566),T18(124180,566),T18(124166,566),T18(124149,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124161,567),T18(124178,567),T18(124172,567),T18(124155,567),T18(124180,567),T18(124166,567),T18(124149,567))
	
	set = AddSet(60000,nil,RAID,17,"PR_TR_17",PRIEST,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120373,120376,120375,120374,120377,120378)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115563,115561,115560,115562,115564)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115563,566),T17(115561,566),T17(115560,566),T17(115562,566),T17(115564,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115563,567),T17(115561,567),T17(115560,567),T17(115562,567),T17(115564,567))

	set = AddSet(50400,nil,RAID,16,"PR_TR_HEALER_16",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99024,99018,99017,99023,99025)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99591,99585,99584,99590,99592)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99117,99120,99119,99131,99118)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99366,99358,99357,99365,99367)
	
	set = AddSet(50400,nil,RAID,16,"PR_TR_CASTER_16",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99020,99005,99004,99019,99021)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99587,99628,99627,99586,99588)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99122,99111,99110,99121,99123)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99360,99363,99362,99359,99361)

	set = AddSet(50400,nil,RAID,15,"PR_TR_HEALER_15",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95926,95929,95928,95925,95927)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95296,95299,95298,95295,95297)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96670,96673,96672,96669,96671)
	
	set = AddSet(50400,nil,RAID,15,"PR_TR_CASTER_15",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95931,95934,95933,95930,95932)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95301,95304,95303,95300,95302)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96675,96678,96677,96674,96676)
	
	set = AddSet(50400,nil,RAID,14,"PR_TR_HEALER_14",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86702,86699,86700,86703,86701)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85362,85359,85360,85363,85361)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87115,87118,87117,87114,87116)

	set = AddSet(50400,nil,RAID,14,"PR_TR_CASTER_14",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86705,86708,86707,86704,86706)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85365,85368,85367,85364,85366)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87120,87123,87122,87119,87121)
	
	set = AddSet(50400,nil,RAID,13,"PR_TR_HEALER_13",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78795,78842,78823,78778,78814)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76358,76361,76360,76357,76359)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78700,78747,78728,78683,78719)

	set = AddSet(50400,nil,RAID,13,"PR_TR_CASTER_13",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78798,78845,78826,78777,78817)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76347,76344,76345,76348,76346)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78703,78750,78731,78682,78722)
	
	set = AddSet(50400,nil,RAID,12,"PR_TR_HEALER_12",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71272,71275,71274,71271,71273)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71528,71531,71530,71527,71529)

	set = AddSet(50400,nil,RAID,12,"PR_TR_CASTER_12",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71277,71280,71279,71276,71278)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71533,71536,71535,71532,71534)
	
	set = AddSet(50400,nil,RAID,11,"PR_TR_HEALER_11",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60258,60262,60259,60275,60261)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65230,65233,65232,65229,65231)

	set = AddSet(50400,nil,RAID,11,"PR_TR_CASTER_11",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60256,60253,60254,60257,60255)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65235,65238,65237,65234,65236)

	set = AddSet(50400,nil,RAID,10,"PR_TR_HEALER_10",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50765,50767,50768,50766,50769)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51178,51175,51176,51179,51177)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51261,51264,51263,51260,51262)

	set = AddSet(50400,nil,RAID,10,"PR_TR_CASTER_10",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50392,50396,50394,50391,50393)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51184,51182,51180,51183,51181)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51255,51257,51259,51256,51258)
	
	set = AddSet(50400,nil,RAID,9,"PR_TR_HEALER_A_09",PRIEST,HEALER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48035,48029,48031,48037,48033)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,47984,47987,47986,47983,47985)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,47914,47981,47936,47982,47980)
	
	set = AddSet(50400,nil,RAID,9,"PR_TR_CASTER_A_09",PRIEST,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48085,48082,48083,48086,48084)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48078,48081,48080,48077,48079)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48073,48076,48075,48072,48074)

	set = AddSet(50400,nil,RAID,9,"PR_TR_HEALER_H_09",PRIEST,HEALER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48058,48061,48060,48057,48059)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48065,48062,48063,48066,48064)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48068,48071,48070,48067,48069)
	
	set = AddSet(50400,nil,RAID,9,"PR_TR_CASTER_H_09",PRIEST,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48088,48091,48090,48087,48089)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48095,48092,48093,48096,48094)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48098,48101,48100,48097,48099)
	
	set = AddSet(50400,nil,RAID,8,"PR_TR_HEALER_08",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45386,45390,45389,45387,45388)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46197,46190,46193,46188,46195)

	set = AddSet(50400,nil,RAID,8,"PR_TR_CASTER_08",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45391,45393,45395,45392,45394)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46172,46165,46168,46163,46170)

	set = AddSet(50400,nil,RAID,7,"PR_TR_HEALER_07",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39514,39518,39515,39519,39517)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40447,40450,40449,40445,40448)

	set = AddSet(50400,nil,RAID,7,"PR_TR_CASTER_07",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39521,39529,39523,39530,39528)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40456,40459,40458,40454,40457)
	
	set = AddSet(50400,nil,RAID,6,"PR_TR_HEALER_06",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_HEALER_06",OBTAIN,TRANSMOG,31063,31069,31066,34435,31060,34527,31068,34562)
	
	set = AddSet(50400,nil,RAID,6,"PR_TR_CASTER_06",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_CASTER_06",OBTAIN,TRANSMOG,31064,31070,31065,34434,31061,34528,31067,34563)

	set = AddSet(50400,nil,RAID,5,"PR_TR_HEALER_05",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_HEALER_05",OBTAIN,TRANSMOG,30152,30154,30150,30151,30153)
	
	set = AddSet(50400,nil,RAID,5,"PR_TR_CASTER_05",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_CASTER_05",OBTAIN,TRANSMOG,30161,30163,30159,30160,30162)

	set = AddSet(50400,nil,RAID,4,"PR_TR_HEALER_04",PRIEST,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_HEALER_04",OBTAIN,TRANSMOG,29049,29054,29050,29055,29053)
	
	set = AddSet(50400,nil,RAID,4,"PR_TR_CASTER_04",PRIEST,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_CASTER_04",OBTAIN,TRANSMOG,29058,29060,29056,29057,29059)

	set = AddSet(50400,nil,RAID,3,"PR_TR_03",PRIEST,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_03",NOOBTAIN,TRANSMOG,22514,22515,22512,22519,22517,22518,22513,22516,23061)

	set = AddSet(50400,nil,RAID,2,"PR_TR_02",PRIEST,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_02",OBTAIN,TRANSMOG,16921,16924,16923,16926,16920,16925,16922,16919)

	set = AddSet(50400,nil,RAID,1,"PR_TR_01",PRIEST,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"PR_TR_01",OBTAIN,TRANSMOG,16813,16816,16815,16819,16812,16817,16814,16811)
				
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"PR_CD_90",PRIEST,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"PR_CD_90",NOOBTAIN,TRANSMOG,90116,90113,90114,90112,90115,90110,90117,90111)
				
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"PR_DG_03",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PR_DG_03",OBTAIN,TRANSMOG,28413,27775,28230,27536,27875)
	
	set = AddSet(50400,nil,DUNGEON,31,"DG_CLOTH_03",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_CLOTH_03",OBTAIN,TRANSMOG,28193,27796,28191,27465,27907)
	
	set = AddSet(50400,nil,DUNGEON,22,"PR_DG_AQ_2",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PR_DG_AQ_2",OBTAIN,TRANSMOG,21348,21350,21351,21352,21349)
	
	set = AddSet(50400,nil,DUNGEON,21,"PR_DG_AQ_1",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"PR_DG_AQ_1",OBTAIN,TRANSMOG,21410,21412,21411)
	
	set = AddSet(50400,nil,DUNGEON,20,"PR_DG_02",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78216,78213,78212,78215,78217,78218,78214,78219)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,22080,22082,22083,22079,22081,22078,22085,22084)
	
	set = AddSet(50400,nil,DUNGEON,1,"PR_DG_01",PRIEST,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78205,78204,78209,78211,78208,78207,78206,78210)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16693,16695,16690,16697,16692,16696,16694,16691)

	-- PvP
	set = AddSet(60200,nil,PVP,18,"PR_PVP_18",PRIEST,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126232,126235,126234,126231,126233)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126115,126118,126117,126114,126116)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125937,125940,125939,125936,125938)
				
	set = AddSet(60200,nil,PVP,18,"PR_PVP_18",PRIEST,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126709,126712,126711,126708,126710)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126592,126595,126594,126591,126593)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126416,126419,126418,126415,126417)
				
	set = AddSet(60200,nil,PVP,17,"PR_PVP_17",PRIEST,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125118,125121,125120,125117,125119)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125001,125004,125003,125000,125002)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124823,124826,124825,124822,124824)
				
	set = AddSet(60200,nil,PVP,17,"PR_PVP_17",PRIEST,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125595,125598,125597,125594,125596)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125478,125481,125480,125477,125479)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125302,125305,125304,125301,125303)
				
	set = AddSet(50400,nil,PVP,16,"PR_PVP_16",PRIEST,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115242,115245,115244,115241,115243)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115118,115121,115120,115117,115119)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115711,115714,115713,115710,115712)
				
	set = AddSet(50400,nil,PVP,16,"PR_PVP_16",PRIEST,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,120019,120022,120021,120018,120020)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119901,119904,119903,119900,119902)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111184,111187,111186,111183,111185)
				
	set = AddSet(50400,nil,PVP,15,"PR_PVP_CASTER_15",PRIEST,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102751,102671,102622,102707,102621)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103084,103087,103086,103083,103136,103085,103135)
				
	set = AddSet(50400,nil,PVP,15,"PR_PVP_HEALER_15",PRIEST,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102703,102750,102681,102615,102704)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103079,103082,103081,103078,102993,103080,102996)
				
	set = AddSet(50400,nil,PVP,15,"PR_PVP_CASTER_15",PRIEST,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103468,103471,103470,103467,103469)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103084,103087,103086,103083,103136,103085,103135)
				
	set = AddSet(50400,nil,PVP,15,"PR_PVP_HEALER_15",PRIEST,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103463,103466,103465,103462,103464)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103079,103082,103081,103078,102993,103080,102996)
				
	set = AddSet(50400,nil,PVP,14,"PR_PVP_CASTER_14",PRIEST,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100417,100423,100421,100415,100419)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100418,100424,100422,100416,100420)
				
	set = AddSet(50400,nil,PVP,14,"PR_PVP_HEALER_14",PRIEST,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100407,100413,100411,100405,100409)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100408,100414,100412,100406,100410)
				
	set = AddSet(50400,nil,PVP,14,"PR_PVP_CASTER_14",PRIEST,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100697,100615,100565,100653,100564)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100418,100424,100422,100416,100420)
				
	set = AddSet(50400,nil,PVP,14,"PR_PVP_HEALER_14",PRIEST,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100649,100696,100627,100558,100650)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100408,100414,100412,100406,100410)
	
end

local function AddRogueSets()
	local set = ""
	
	-- Legendary
	set = AddSet(60200,nil,LEGENDARY,100,"LG_MELEE_AGI_100",ROGUE,MELEE,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_MELEE_AGI_100",OBTAIN,NOTRANSMOG,124636)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",NOOBTAIN,TRANSMOG,102248)
	
	set = AddSet(50400,nil,LEGENDARY,85,"LG_ROGUE_85",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_ROGUE_85",OBTAIN,TRANSMOG,77949,77950)
	
	set = AddSet(50400,nil,LEGENDARY,70,"LG_MELEE_70",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_70",OBTAIN,TRANSMOG,32837,32838)

	-- Raid
	set = AddSet(60200,nil,RAID,18,"RO_TR_18",ROGUE,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128130,128121,128125,128137,128131,128054)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124263,124274,124248,124257,124269,124250)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124263,566),T18(124274,566),T18(124248,566),T18(124257,566),T18(124269,566),T18(124250,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124263,567),T18(124274,567),T18(124248,567),T18(124257,567),T18(124269,567),T18(124250,567))
	
	set = AddSet(60000,nil,RAID,17,"RO_TR_17",ROGUE,MELEE,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120382,120381,120380,120384,120379,120383)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115572,115574,115570,115571,115573)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115572,566),T17(115574,566),T17(115570,566),T17(115571,566),T17(115573,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115572,567),T17(115574,567),T17(115570,567),T17(115571,567),T17(115573,567))

	set = AddSet(50400,nil,RAID,16,"RO_TR_MELEE_16",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99008,99010,99006,99007,99009)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99631,99635,99629,99630,99634)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99114,99116,99112,99113,99115)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99348,99350,99356,99355,99349)

	set = AddSet(50400,nil,RAID,15,"RO_TR_MELEE_15",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,96681,96683,96679,96680,96682)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95307,95309,95305,95306,95308)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,95937,95939,95935,95936,95938)

	set = AddSet(50400,nil,RAID,14,"RO_TR_MELEE_14",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86641,86639,86643,86642,86640)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85301,85299,85303,85302,85300)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,86641,86639,86643,86642,86640)

	set = AddSet(50400,nil,RAID,13,"RO_TR_MELEE_13",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78794,78833,78759,78774,78803)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,77025,77027,77023,77024,77026)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78699,78738,78664,78679,78708)

	set = AddSet(50400,nil,RAID,12,"RO_TR_MELEE_12",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71047,71049,71045,71046,71048)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71539,71541,71537,71538,71540)

	set = AddSet(50400,nil,RAID,11,"RO_TR_MELEE_11",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60299,60302,60301,60298,60300)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65241,65243,65239,65240,65242)

	set = AddSet(50400,nil,RAID,10,"RO_TR_MELEE_10",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50089,50105,50087,50088,50090)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51187,51185,51189,51188,51186)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51252,51254,51250,51251,51253)

	set = AddSet(50400,nil,RAID,9,"RO_TR_MELEE_A_09",ROGUE,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48218,48221,48219,48222,48220)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48225,48227,48223,48224,48226)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48230,48228,48232,48231,48229)
				
	set = AddSet(50400,nil,RAID,9,"RO_TR_MELEE_H_09",ROGUE,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48245,48247,48243,48244,48246)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48240,48238,48242,48241,48239)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48235,48237,48233,48234,48236)

	set = AddSet(50400,nil,RAID,8,"RO_TR_MELEE_08",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45398,45400,45396,45397,45399)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46125,46127,46123,46124,46126)

	set = AddSet(50400,nil,RAID,7,"RO_TR_MELEE_07",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39561,39565,39558,39560,39564)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40499,40502,40495,40496,40500)

	set = AddSet(50400,nil,RAID,6,"RO_TR_MELEE_06",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_MELEE_06",OBTAIN,TRANSMOG,31027,31030,31028,34448,31026,34558,31029,34575)

	set = AddSet(50400,nil,RAID,5,"RO_TR_MELEE_05",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_MELEE_05",OBTAIN,TRANSMOG,30146,30149,30144,30145,30148)

	set = AddSet(50400,nil,RAID,4,"RO_TR_MELEE_04",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_MELEE_04",OBTAIN,TRANSMOG,29044,29047,29045,29048,29046)

	set = AddSet(50400,nil,RAID,3,"RO_TR_03",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_03",NOOBTAIN,TRANSMOG,22478,22479,22476,22483,22481,22482,22477,22480,23060)

	set = AddSet(50400,nil,RAID,2,"RO_TR_02",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_02",OBTAIN,TRANSMOG,16908,16832,16905,16911,16907,16910,16909,16906)

	set = AddSet(50400,nil,RAID,1,"RO_TR_01",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RO_TR_01",OBTAIN,TRANSMOG,16821,16823,16820,16825,16826,16827,16822,16824)
				
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"RO_CD_90",ROGUE,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"RO_CD_90",NOOBTAIN,TRANSMOG,90120,90125,90122,90126,90123,90119,90124,90121)
				
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"RO_DG_03",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"RO_DG_03",OBTAIN,TRANSMOG,28414,27776,28204,27509,27908)
	
	set = AddSet(50400,nil,DUNGEON,31,"DG_LEATHER_03",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_LEATHER_03",OBTAIN,TRANSMOG,28224,27797,28264,27531,27837)
	
	set = AddSet(50400,nil,DUNGEON,22,"RO_DG_AQ_2",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"RO_DG_AQ_2",OBTAIN,TRANSMOG,21360,21361,21364,21362,21359)
	
	set = AddSet(50400,nil,DUNGEON,21,"RO_DG_AQ_1",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"RO_DG_AQ_1",OBTAIN,TRANSMOG,21404,21406,21405)
	
	set = AddSet(50400,nil,DUNGEON,20,"RO_DG_02",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78263,78267,78269,78264,78266,78265,78268,78262)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,22005,22008,22009,22004,22006,22002,22007,22003)
	
	set = AddSet(50400,nil,DUNGEON,10,"RO_DG_01",ROGUE,MELEE,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78260,78261,78254,78255,78257,78259,78258,78256)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16707,16708,16721,16710,16712,16713,16709,16711)

	-- PvP
	set = AddSet(60200,nil,PVP,18,"RO_PVP_18",ROGUE,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126238,126240,126236,126237,126239)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126121,126123,126119,126120,126122)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125943,125945,125941,125942,125944)
				
	set = AddSet(60200,nil,PVP,18,"RO_PVP_18",ROGUE,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126715,126717,126713,126714,126716)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126598,126600,126596,126597,126599)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126422,126424,126420,126421,126423)
				
	set = AddSet(60200,nil,PVP,17,"RO_PVP_17",ROGUE,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125124,125126,125122,125123,125125)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125007,125009,125005,125006,125008)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124829,124831,124827,124828,124830)
				
	set = AddSet(60200,nil,PVP,17,"RO_PVP_17",ROGUE,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125601,125603,125599,125600,125602)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125484,125486,125483,125483,125485)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125308,125310,125306,125307,125309)
				
	set = AddSet(50400,nil,PVP,16,"RO_PVP_16",ROGUE,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115248,115250,115246,115247,115249)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115124,115126,115122,115123,115125)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115717,115719,115715,115716,115718)
				
	set = AddSet(50400,nil,PVP,16,"RO_PVP_16",ROGUE,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,120025,120027,120023,120024,120026)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119907,119909,119905,119906,119908)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111190,111192,111188,111189,111191)
				
	set = AddSet(50400,nil,PVP,15,"RO_PVP_MELEE_15",ROGUE,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102710,102731,102727,102663,102730)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103092,103094,103090,103091,103088,103093,103089)
				
	set = AddSet(50400,nil,PVP,15,"RO_PVP_MELEE_15",ROGUE,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103477,103479,103475,103476,103478)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103092,103094,103090,103091,103088,103093,103089)
				
	set = AddSet(50400,nil,PVP,14,"RO_PVP_MELEE_14",ROGUE,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100434,100438,100430,100432,100436)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100435,100439,100431,100433,100437)
				
	set = AddSet(50400,nil,PVP,14,"RO_PVP_MELEE_14",ROGUE,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100656,100677,100673,100607,100676)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100435,100439,100431,100433,100437)
	
end

local function AddShamanSets()
	local set = ""
	
	-- Legendary
	set = AddSet(60200,nil,LEGENDARY,100,"LG_CASTER_INT_100",SHAMAN,CASTER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_CASTER_INT_100",OBTAIN,NOTRANSMOG,124638)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_MELEE_AGI_100",SHAMAN,MELEE,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_MELEE_AGI_100",OBTAIN,NOTRANSMOG,124636)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_HEALER_INT_100",SHAMAN,HEALER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_HEALER_INT_100",OBTAIN,NOTRANSMOG,124635)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",NOOBTAIN,TRANSMOG,102246)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_AGI_90",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_AGI_90",NOOBTAIN,TRANSMOG,102248)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_HEALER_INT_90",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_INT_90",NOOBTAIN,TRANSMOG,102247)
	
	set = AddSet(50400,nil,LEGENDARY,80,"LG_HEALER_80",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_HEALER_80",OBTAIN,TRANSMOG,46017)
	
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",OBTAIN,TRANSMOG,17182)
	
	-- Raid	
	set = AddSet(60200,nil,RAID,18,"SH_TR_18",SHAMAN,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128132,128122,128126,128138,128133,128080)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124297,124308,124303,124293,124309,124302,124287)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124297,566),T18(124308,566),T18(124303,566),T18(124293,566),T18(124309,566),T18(124302,566),T18(124287,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124297,567),T18(124308,567),T18(124303,567),T18(124293,567),T18(124309,567),T18(124302,567),T18(124287,567))
	
	set = AddSet(60000,nil,RAID,17,"SH_TR_17",SHAMAN,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120390,120388,120389,120386,120385,120387)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115579,115576,115577,115578,115575)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115579,566),T17(115576,566),T17(115577,566),T17(115578,566),T17(115575,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115579,567),T17(115576,567),T17(115577,567),T17(115578,567),T17(115575,567))
	
	set = AddSet(50400,nil,RAID,16,"SH_TR_CASTER_16",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99089,99091,99087,99088,99090)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99645,99647,99579,99580,99646)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99093,99095,99106,99092,99094)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99332,99334,99344,99345,99333)
	
	set = AddSet(50400,nil,RAID,16,"SH_TR_MELEE_16",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,98983,98977,98992,98993,98984)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99649,99663,99615,99616,99650)
  			AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99103,99105,99101,99102,99104)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99341,99343,99347,99340,99342)
	
	set = AddSet(50400,nil,RAID,16,"SH_TR_HEALER_16",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,98989,98991,99011,98988,98990)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99612,99614,99636,99611,99613)
  			AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99109,99100,99107,99108,99099)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99353,99346,99351,99352,99354)
	
	set = AddSet(50400,nil,RAID,15,"SH_TR_CASTER_15",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95952,95954,95950,95951,95953)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95322,95324,95320,95321,95323)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96696,96698,96694,96695,96697)

	set = AddSet(50400,nil,RAID,15,"SH_TR_MELEE_15",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95947,95949,95945,95946,95948)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95317,95319,95315,95316,95318)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96691,96693,96689,96690,96692)

	set = AddSet(50400,nil,RAID,15,"SH_TR_HEALER_15",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95942,95944,95940,95941,95943)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95312,95314,95310,95311,95313)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96686,96688,96684,96685,96687)
	
	set = AddSet(50400,nil,RAID,14,"SH_TR_CASTER_14",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86631,86633,86629,86630,86632)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85291,85293,85289,85290,85292)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87141,87143,87139,87140,87142)

	set = AddSet(50400,nil,RAID,14,"SH_TR_MELEE_14",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86626,86624,86628,86627,86625)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85286,85284,85288,85287,85285)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87136,87138,87134,87135,87137)

	set = AddSet(50400,nil,RAID,14,"SH_TR_HEALER_14",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86691,86689,86693,86692,86690)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85351,85349,85353,85352,85350)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87131,87133,87129,87130,87132)
	
	set = AddSet(50400,nil,RAID,13,"SH_TR_CASTER_13",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78780,78836,78818,78761,78806)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,77037,77035,77039,77038,77036)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78685,78741,78723,78666,78711)

	set = AddSet(50400,nil,RAID,13,"SH_TR_MELEE_13",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78781,78828,78819,78762,78799)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,77042,77044,77040,77041,77043)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78686,78733,78724,78667,78704)

	set = AddSet(50400,nil,RAID,13,"SH_TR_HEALER_13",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78786,78834,78820,78767,78813)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76758,76760,76756,76757,76759)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78691,78739,78725,78672,78718)

	set = AddSet(50400,nil,RAID,12,"SH_TR_CASTER_12",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71293,71295,71291,71292,71294)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71554,71556,71552,71553,71555)

	set = AddSet(50400,nil,RAID,12,"SH_TR_MELEE_12",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71303,71305,71301,71302,71304)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71549,71551,71547,71548,71550)

	set = AddSet(50400,nil,RAID,12,"SH_TR_HEALER_12",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71298,71300,71296,71297,71299)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71544,71546,71542,71543,71545)

	set = AddSet(50400,nil,RAID,11,"SH_TR_CASTER_11",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60315,60317,60313,60314,60316)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65256,65258,65254,65255,65257)

	set = AddSet(50400,nil,RAID,11,"SH_TR_MELEE_11",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60320,60322,60318,60319,60321)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65251,65253,65249,65250,65252)

	set = AddSet(50400,nil,RAID,11,"SH_TR_HEALER_11",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60308,60311,60309,60312,60310)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65246,65248,65244,65245,65247)
	
	set = AddSet(50400,nil,RAID,10,"SH_TR_CASTER_10",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50843,50845,50841,50842,50844)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51202,51204,51200,51201,51203)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51237,51235,51239,51238,51236)

	set = AddSet(50400,nil,RAID,10,"SH_TR_MELEE_10",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50832,50834,50830,50831,50833)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51197,51199,51195,51196,51198)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51242,51240,51244,51243,51241)

	set = AddSet(50400,nil,RAID,10,"SH_TR_HEALER_10",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50837,50839,50835,50836,50838)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51192,51194,51190,51191,51193)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51247,51245,51249,51248,51246)	
	
	set = AddSet(50400,nil,RAID,9,"SH_TR_CASTER_A_09",SHAMAN,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48313,48315,48310,48312,48314)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48318,48320,48316,48317,48319)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48323,48321,48325,48324,48322)

	set = AddSet(50400,nil,RAID,9,"SH_TR_MELEE_A_09",SHAMAN,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48343,48345,48341,48342,48344)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48348,48350,48346,48347,48349)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48353,48351,48355,48354,48352)

	set = AddSet(50400,nil,RAID,9,"SH_TR_HEALER_A_09",SHAMAN,HEALER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48280,48283,48281,48284,48282)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48287,48289,48285,48286,48288)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48292,48290,48294,48293,48291)

	set = AddSet(50400,nil,RAID,9,"SH_TR_CASTER_H_09",SHAMAN,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48338,48340,48336,48337,48339)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48333,48331,48335,48334,48332)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48328,48330,48326,48327,48329)

	set = AddSet(50400,nil,RAID,9,"SH_TR_MELEE_H_09",SHAMAN,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48368,48370,48366,48367,48369)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48363,48361,48365,48364,48362)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48358,48360,48356,48357,48359)

	set = AddSet(50400,nil,RAID,9,"SH_TR_HEALER_H_09",SHAMAN,HEALER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48297,48299,48295,48296,48298)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48302,48304,48300,48301,48303)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48307,48309,48305,48306,48308)
	
	set = AddSet(50400,nil,RAID,8,"SH_TR_CASTER_08",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45408,45410,45411,45406,45409)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46209,46211,46206,46207,46210)

	set = AddSet(50400,nil,RAID,8,"SH_TR_MELEE_08",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45412,45415,45413,45414,45416)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46212,46203,46205,46200,46208)

	set = AddSet(50400,nil,RAID,8,"SH_TR_HEALER_08",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45402,45404,45405,45401,45403)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46201,46204,46198,46199,46202)
	
	set = AddSet(50400,nil,RAID,7,"SH_TR_CASTER_07",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39594,39596,39592,39593,39595)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40516,40518,40514,40515,40517)

	set = AddSet(50400,nil,RAID,7,"SH_TR_MELEE_07",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39602,39604,39597,39601,39603)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40521,40524,40523,40520,40522)

	set = AddSet(50400,nil,RAID,7,"SH_TR_HEALER_07",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39583,39590,39588,39591,39589)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40510,40513,40508,40509,40512)
	
	set = AddSet(50400,nil,RAID,6,"SH_TR_CASTER_06",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_CASTER_06",OBTAIN,TRANSMOG,31014,31023,31017,34437,31008,34542,31020,34566)
	
	set = AddSet(50400,nil,RAID,6,"SH_TR_MELEE_06",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_MELEE_06",OBTAIN,TRANSMOG,31015,31024,31018,34439,31011,34545,31021,34567)
	
	set = AddSet(50400,nil,RAID,6,"SH_TR_HEALER_06",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_HEALER_06",OBTAIN,TRANSMOG,31012,31022,31016,34438,31007,34543,31019,34565)
	
	set = AddSet(50400,nil,RAID,5,"SH_TR_CASTER_05",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_CASTER_05",OBTAIN,TRANSMOG,30171,30173,30169,30170,30172)
	
	set = AddSet(50400,nil,RAID,5,"SH_TR_MELEE_05",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_MELEE_05",OBTAIN,TRANSMOG,30190,30194,30185,30189,30192)
	
	set = AddSet(50400,nil,RAID,5,"SH_TR_HEALER_05",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_HEALER_05",OBTAIN,TRANSMOG,30166,30168,30164,30165,30167)
	
	set = AddSet(50400,nil,RAID,4,"SH_TR_CASTER_04",SHAMAN,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_CASTER_04",OBTAIN,TRANSMOG,29035,29037,29033,29034,29036)
	
	set = AddSet(50400,nil,RAID,4,"SH_TR_MELEE_04",SHAMAN,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_MELEE_04",OBTAIN,TRANSMOG,29040,29043,29038,29039,29042)
	
	set = AddSet(50400,nil,RAID,4,"SH_TR_HEALER_04",SHAMAN,HEALER,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_HEALER_04",OBTAIN,TRANSMOG,29028,29031,29029,29032,29030)
	
	set = AddSet(50400,nil,RAID,3,"SH_TR_03",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_03",NOOBTAIN,TRANSMOG,22466,22467,22464,22471,22469,22470,22465,22468,23065)
	
	set = AddSet(50400,nil,RAID,2,"SH_TR_02",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_02",OBTAIN,TRANSMOG,16947,16945,16950,16943,16948,16944,16946,16949)
	
	set = AddSet(50400,nil,RAID,1,"SH_TR_01",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"SH_TR_01",OBTAIN,TRANSMOG,16842,16844,16841,16840,16839,16838,16843,16837)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,90,"SH_CD_90",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"SH_CD_90",NOOBTAIN,TRANSMOG,90132,90134,90130,90127,90131,90128,90133,90129)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"SH_DG_03",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"SH_DG_03",OBTAIN,TRANSMOG,28349,27802,28231,27510,27909)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_MAIL_03",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_MAIL_03",OBTAIN,TRANSMOG,28192,27713,28401,27528,27936)
				
	set = AddSet(50400,nil,DUNGEON,22,"SH_DG_AQ_2",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"SH_DG_AQ_2",OBTAIN,TRANSMOG,21372,21376,21374,21375,21373)
				
	set = AddSet(50400,nil,DUNGEON,21,"SH_DG_AQ_1",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"SH_DG_AQ_1",OBTAIN,TRANSMOG,21398,21400,21399)
				
	set = AddSet(50400,nil,DUNGEON,20,"SH_DG_02",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78294,78299,78300,78296,78295,78297,78301,78298)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,22097,22101,22102,22095,22099,22098,22100,22096)
				
	set = AddSet(50400,nil,DUNGEON,10,"SH_DG_01",SHAMAN,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78286,78288,78290,78289,78291,78293,78287,78292)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16667,16669,16666,16671,16672,16673,16668,16670)
	
	-- PvP
	set = AddSet(60200,nil,PVP,18,"SH_PVP_18",SHAMAN,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126243,126245,126241,126242,126244)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126126,126128,126124,126125,126127)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125948,125950,125946,125947,125949)
				
	set = AddSet(60200,nil,PVP,18,"SH_PVP_18",SHAMAN,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126720,126722,126718,126719,126721)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126603,126605,126601,126602,126604)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126427,126429,126425,126426,126428)
				
	set = AddSet(60200,nil,PVP,17,"SH_PVP_17",SHAMAN,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125129,125131,125127,125128,125130)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125012,125014,125010,125011,125013)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124834,124836,124832,124833,124835)
				
	set = AddSet(60200,nil,PVP,17,"SH_PVP_17",SHAMAN,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125606,125608,125604,125605,125607)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125489,125491,125487,125488,125490)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125313,125315,125311,125312,125314)
				
	set = AddSet(50400,nil,PVP,16,"SH_PVP_16",SHAMAN,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115253,115255,115251,115252,115254)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115129,115131,115127,115128,115130)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115722,115724,115720,115721,115723)
				
	set = AddSet(50400,nil,PVP,16,"SH_PVP_16",SHAMAN,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,120030,120032,120028,120029,120031)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119912,119915,119910,119911,119913)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111195,111197,111193,111194,111196)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_CASTER_15",SHAMAN,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102693,102637,102743,102692,102781)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103111,103113,103109,103108,103110,103112,103097)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_HEALER_15",SHAMAN,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102718,102655,102717,102774,102719)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103100,103102,103098,103099,103095,103101,103096)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_MELEE_15",SHAMAN,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102714,102629,102759,102742,102778)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103105,103107,103103,103104,103034,103106,103036)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_CASTER_15",SHAMAN,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103498,103500,103496,103497,103499)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103110,103097,102108,103109,103111,103112,103113)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_HEALER_15",SHAMAN,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103487,103489,103485,103486,103488)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103099,103095,103096,103098,103100,103101,103102)
				
	set = AddSet(50400,nil,PVP,15,"SH_PVP_MELEE_15",SHAMAN,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103492,103494,103490,103491,103493)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103104,103034,103036,103103,103105,103106,103107)
				
	set = AddSet(50400,nil,PVP,14,"SH_PVP_CASTER_14",SHAMAN,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100474,100478,100470,100472,100476)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100475,100479,100471,100473,100477)
				
	set = AddSet(50400,nil,PVP,14,"SH_PVP_HEALER_14",SHAMAN,HEALER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100452,100456,100448,100450,100454)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100453,100457,100449,100451,100455)
				
	set = AddSet(50400,nil,PVP,14,"SH_PVP_MELEE_14",SHAMAN,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100462,100466,100458,100460,100464)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100463,100467,100459,100461,100465)
				
	set = AddSet(50400,nil,PVP,14,"SH_PVP_CASTER_14",SHAMAN,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE,OBTAIN,TRANSMOG",100639,100580,100689,100638,100727)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100475,100479,100471,100473,100477)
				
	set = AddSet(50400,nil,PVP,14,"SH_PVP_HEALER_14",SHAMAN,HEALER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100664,100599,100663,100720,100665)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100453,100457,100449,100451,100455)
				
	set = AddSet(50400,nil,PVP,14,"SH_PVP_MELEE_14",SHAMAN,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100462,100466,100458,100460,100464)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100463,100467,100459,100461,100465)
				
end

local function AddWarlockSets()
	local set = ""
	
  -- Legendaries
	set = AddSet(60200,nil,LEGENDARY,100,"LG_CASTER_INT_100",WARLOCK,CASTER,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_CASTER_INT_100",OBTAIN,NOTRANSMOG,124638)
	
	set = AddSet(50400,nil,LEGENDARY,90,"LG_CASTER_INT_90",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_CASTER_INT_90",NOOBTAIN,TRANSMOG,102246)
				
	set = AddSet(50400,nil,LEGENDARY,85,"LG_85",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_85",OBTAIN,TRANSMOG,71086)
	
	-- Raid Tier Sets
	set = AddSet(60200,nil,RAID,18,"WK_TR_18",WARLOCK,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128128,128120,128124,128136,128129,128052)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124162,124179,124173,124156,124181,124167)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124162,566),T18(124179,566),T18(124173,566),T18(124156,566),T18(124181,566),T18(124167,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124162,567),T18(124179,567),T18(124173,567),T18(124156,567),T18(124181,567),T18(124167,567))
	
	-- Tier 17
	set = AddSet(60000,nil,RAID,17,"WK_TR_17",WARLOCK,CASTER,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120373,120376,120375,120374,120377,120378)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115586,115589,115588,115585,115587)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115586,566),T17(115589,566),T17(115588,566),T17(115585,566),T17(115587,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115586,567),T17(115589,567),T17(115588,567),T17(115585,567),T17(115587,567))
				
	-- Tier 16
	set = AddSet(50400,nil,RAID,16,"WK_TR_CASTER_16",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99054,99045,99056,99053,99055)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99568,99601,99570,99567,99569)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99097,99205,99204,99096,99098)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99425,99417,99416,99424,99426)
				
	-- Tier 15
	set = AddSet(50400,nil,RAID,15,"WK_TR_CASTER_15",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95982,95985,95984,95981,95983)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95326,95329,95328,95325,95327)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96726,96729,96728,96725,96727)
				
	-- Tier 14
	set = AddSet(50400,nil,RAID,14,"WK_TR_CASTER_14",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86710,86713,86712,86709,86711)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85370,85373,85372,85369,85371)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87188,87191,87190,87187,87189)
				
	-- Tier 13
	set = AddSet(50400,nil,RAID,13,"WK_TR_CASTER_13",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78797,78844,78825,78776,78816)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76342,76339,76340,76343,76341)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78702,78749,78730,78681,78721)
				
	-- Tier 12
	set = AddSet(50400,nil,RAID,12,"WK_TR_CASTER_12",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71282,71285,71284,71281,71283)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71595,71598,71597,71594,71596)
				
	-- Tier 11
	set = AddSet(50400,nil,RAID,11,"WK_TR_CASTER_11",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60249,60252,60251,60248,60250)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65260,65263,65262,65259,65261)
				
	-- Tier 10
	set = AddSet(50400,nil,RAID,10,"WK_TR_CASTER_10",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50241,50244,50243,50240,50242)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51208,51205,51206,51209,51207)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51231,51234,51233,51230,51232)
				
	-- Tier 9
	set = AddSet(50400,nil,RAID,9,"WK_TR_CASTER_A_09",WARLOCK,CASTER,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,47784,47787,47786,47783,47785)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,47778,47781,47779,47782,47780)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,47789,47792,47791,47788,47790)
				
	set = AddSet(50400,nil,RAID,9,"WK_TR_CASTER_H_09",WARLOCK,CASTER,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,47801,47798,47799,47802,47800)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,47804,47807,47806,47803,47805)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,47796,47793,47794,47797,47795)
				
	-- Tier 8
	set = AddSet(50400,nil,RAID,8,"WK_TR_CASTER_08",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45417,45422,45421,45419,45420)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46140,46136,46137,46135,46139)
				
	-- Tier 7
	set = AddSet(50400,nil,RAID,7,"WK_TR_CASTER_07",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39496,39499,39497,39500,39498)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40421,40424,40423,40420,40422)	
				
	-- Tier 6
	set = AddSet(50400,nil,RAID,6,"WK_TR_CASTER_06",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_CASTER_06",OBTAIN,TRANSMOG,31051,31054,31052,34436,31050,34541,31053,34564)
				
	-- Tier 5
	set = AddSet(50400,nil,RAID,5,"WK_TR_CASTER_05",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_CASTER_05",OBTAIN,TRANSMOG,30212,30215,30214,30211,30213)
				
	-- Tier 4
	set = AddSet(50400,nil,RAID,4,"WK_TR_CASTER_04",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_CASTER_04",OBTAIN,TRANSMOG,28963,28967,28964,28968,28966)
				
	-- Tier 3
	set = AddSet(50400,nil,RAID,3,"WK_TR_03",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_03",NOOBTAIN,TRANSMOG,22506,22507,22504,22511,22509,22510,22505,22508,23063)
				
	-- Tier 2
	set = AddSet(50400,nil,RAID,2,"WK_TR_02",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_02",OBTAIN,TRANSMOG,16929,16932,16931,16934,16928,16933,16930,16927)
				
	-- Tier 1
	set = AddSet(50400,nil,RAID,1,"WK_TR_01",WARLOCK,CASTER,ANY)
				AddVariant(50400,nil,RAID,set,"WK_TR_01",OBTAIN,TRANSMOG,16808,16807,16809,16804,16805,16806,16810,16803)
				
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"WK_CD_90",WARLOCK,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"WK_CD_90",NOOBTAIN,TRANSMOG,90142,90138,90140,90139,90141,90136,90143,90137)
				
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"WK_DG_03",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"WK_DG_03",OBTAIN,TRANSMOG,28415,27778,28232,27537,27948)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_CLOTH_03",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"DG_CLOTH_03",OBTAIN,TRANSMOG,28193,27796,28191,27465,27907)
				
	set = AddSet(50400,nil,DUNGEON,22,"WK_DG_AQ_2",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"WK_DG_AQ_2",OBTAIN,TRANSMOG,21337,21335,21334,21336,21338)
				
	set = AddSet(50400,nil,DUNGEON,21,"WK_DG_AQ_1",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"WK_DG_AQ_1",OBTAIN,TRANSMOG,21416,21418,21417)
				
	set = AddSet(50400,nil,DUNGEON,20,"WK_DG_02",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78230,78234,78237,78232,78236,78233,78231,78235)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,22074,22073,22075,22071,22077,22070,22072,22076)
				
	set = AddSet(50400,nil,DUNGEON,10,"WK_DG_01",WARLOCK,CASTER,ANY)	
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78227,78226,78225,78229,78223,78222,78228,78224)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16698,16701,16700,16703,16705,16702,16699,16704)

	-- PvP
	set = AddSet(60200,nil,PVP,18,"WK_PVP_18",WARLOCK,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126259,126262,126261,126258,126260)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126168,126171,126170,126167,126169)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125990,125993,125992,125989,125991)
				
	set = AddSet(60200,nil,PVP,18,"WK_PVP_18",WARLOCK,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126736,126739,126738,126735,126737)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126645,126648,126647,126644,126646)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126467,126470,126469,126466,126468)
				
	set = AddSet(60200,nil,PVP,17,"WK_PVP_17",WARLOCK,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125145,125148,125147,125144,125146)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125054,125057,125056,125053,125055)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124876,124879,124878,124875,124877)
				
	set = AddSet(60200,nil,PVP,17,"WK_PVP_17",WARLOCK,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125622,125625,125624,125621,125623)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125531,125534,125533,125530,125532)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125353,125356,125355,125352,125354)
				
	set = AddSet(50400,nil,PVP,16,"WK_PVP_16",WARLOCK,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115259,115262,115261,115258,115260)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115162,115165,115164,115161,115163)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115762,115765,115764,115761,115763)
				
	set = AddSet(50400,nil,PVP,16,"WK_PVP_16",WARLOCK,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,120036,120039,120038,120035,120037)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119939,119942,119941,119938,119940)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111235,111238,111237,111234,111236)
				
	set = AddSet(50400,nil,PVP,15,"WK_PVP_CASTER_15",WARLOCK,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102726,102682,102661,102725,102755)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103124,103127,103126,103123,102992,103125,102995)
				
	set = AddSet(50400,nil,PVP,15,"WK_PVP_CASTER_15",WARLOCK,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103521,103524,103523,103520,103522)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103124,103127,103126,103123,102992,103125,102995)
				
	set = AddSet(50400,nil,PVP,14,"WK_PVP_CASTER_14",WARLOCK,CASTER,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100512,100518,100516,100510,100514)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100513,100519,100517,100511,100515)
				
	set = AddSet(50400,nil,PVP,14,"WK_PVP_CASTER_14",WARLOCK,CASTER,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100672,100628,100605,100671,100701)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100513,100519,100517,100511,100515)
end

local function AddWarriorSets()
	local set = ""
	
  -- Legendaries
	set = AddSet(60200,nil,LEGENDARY,100,"LG_MELEE_STR_100",WARRIOR,MELEE,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_MELEE_STR_100",OBTAIN,NOTRANSMOG,124634)
	set = AddSet(60200,nil,LEGENDARY,100,"LG_TANK_100",WARRIOR,TANK,ANY)
				AddVariant(60200,nil,LEGENDARY,set,"LG_TANK_100",OBTAIN,NOTRANSMOG,124637)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_MELEE_STR_90",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_STR_90",NOOBTAIN,TRANSMOG,102249)
				
	set = AddSet(50400,nil,LEGENDARY,90,"LG_TANK_STR_90",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_TANK_STR_90",NOOBTAIN,TRANSMOG,102250)
				
	set = AddSet(50400,nil,LEGENDARY,80,"LG_80",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_80",OBTAIN,TRANSMOG,49623)
				
	set = AddSet(50400,nil,LEGENDARY,70,"LG_MELEE_70",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_MELEE_70",OBTAIN,TRANSMOG,32837,32838)
				
	set = AddSet(50400,nil,LEGENDARY,60,"LG_60",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,LEGENDARY,set,"LG_60",OBTAIN,TRANSMOG,17182)

	-- Raid Tier Sets
	set = AddSet(60200,nil,RAID,18,"WR_TR_18",WARRIOR,ANY,ANY)
				AddVariant(60200,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,128134,128123,128127,128139,128135,128032)
				AddVariant(60200,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,124334,124346,124319,124329,124349,124340,124320)	-- No Bonus
				AddVariant(60200,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T18(124334,566),T18(124346,566),T18(124319,566),T18(124329,566),T18(124349,566),T18(124340,566),T18(124320,566))
				AddVariant(60200,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T18(124334,567),T18(124346,567),T18(124319,567),T18(124329,567),T18(124349,567),T18(124340,567),T18(124320,567))
	
	-- Tier 17
	set = AddSet(60000,nil,RAID,17,"WR_TR_17",WARRIOR,ANY,ANY)
				AddVariant(60000,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,120396,120395,120393,120392,120391,120394)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,115584,115581,115582,115583,115580)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,T17(115584,566),T17(115581,566),T17(115582,566),T17(115583,566),T17(115580,566))
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,T17(115584,567),T17(115581,567),T17(115582,567),T17(115583,567),T17(115580,567))

	-- Tier 16
	set = AddSet(50400,nil,RAID,16,"WR_TR_MELEE_16",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99046,99036,99047,99034,99035)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99602,99561,99603,99559,99560)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99206,99200,99197,99198,99199)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99418,99414,99411,99412,99413)

	set = AddSet(50400,nil,RAID,16,"WR_TR_TANK_16",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,99032,99030,99037,99038,99033)
				AddVariant(60000,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,99557,99597,99562,99563,99558)
				AddVariant(60000,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,99203,99196,99201,99202,99195)
				AddVariant(60000,nil,RAID,set,"MYTHIC",OBTAIN,TRANSMOG,99409,99407,99415,99408,99410)
	
	-- Tier 15
	set = AddSet(50400,nil,RAID,15,"WR_TR_MELEE_15",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95986,95990,95987,95988,95989)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95330,95334,95331,95332,95333)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96730,96734,96731,96732,96733)

	set = AddSet(50400,nil,RAID,15,"WR_TR_TANK_15",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,95993,95995,95991,95992,95994)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,95337,95339,95335,95336,95338)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,96737,96739,96735,96736,96738)
	
	-- Tier 14
	set = AddSet(50400,nil,RAID,14,"WR_TR_MELEE_14",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86673,86669,86672,86671,86670)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85333,85329,85332,85331,85330)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87192,87196,87193,87194,87195)

	set = AddSet(50400,nil,RAID,14,"WR_TR_TANK_14",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,86666,86664,86668,86667,86665)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,85326,85324,85328,85327,85325)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,87199,87201,87197,87198,87200)
	
	-- Tier 13
	set = AddSet(50400,nil,RAID,13,"WR_TR_MELEE_13",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78783,78830,78752,78763,78801)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76983,76987,76984,76985,76986)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78688,78735,78657,78668,78706)

	set = AddSet(50400,nil,RAID,13,"WR_TR_TANK_13",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"RAIDFINDER",OBTAIN,TRANSMOG,78784,78829,78753,78764,78800)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,76990,76992,76988,76989,76991)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,78689,78734,78658,78669,78705)
	
	-- Tier 12
	set = AddSet(50400,nil,RAID,12,"WR_TR_MELEE_12",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,71070,71072,71068,71069,71071)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71599,71603,71600,71601,71602)

	set = AddSet(50400,nil,RAID,12,"WR_TR_TANK_12",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,70944,70941,70945,70943,70942)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,71606,71608,71604,71605,71607)	
	
	-- Tier 11
	set = AddSet(50400,nil,RAID,11,"WR_TR_MELEE_11",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60325,60327,60323,60326,60324)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65266,65268,65264,65265,65267)

	set = AddSet(50400,nil,RAID,11,"WR_TR_TANK_11",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,60328,60331,60329,60332,60330)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,65271,65273,65269,65270,65272)
	
	-- Tier 10
	set = AddSet(50400,nil,RAID,10,"WR_TR_MELEE_10",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50080,50082,50078,50079,50081)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51212,51210,51214,51213,51211)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51227,51229,51225,51226,51228)

	set = AddSet(50400,nil,RAID,10,"WR_TR_TANK_10",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,50848,50846,50850,50849,50847)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,51218,51215,51219,51217,51216)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,51221,51224,51220,51222,51223)

	-- Tier 9
	set = AddSet(50400,nil,RAID,9,"WR_TR_MELEE_A_09",WARRIOR,MELEE,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48371,48374,48372,48375,48373)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48378,48380,48376,48377,48379)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48383,48381,48385,48384,48382)
	
	set = AddSet(50400,nil,RAID,9,"WR_TR_TANK_A_09",WARRIOR,TANK,ALLIANCE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48429,48448,48436,48449,48445)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48430,48454,48450,48452,48446)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48433,48455,48451,48453,48447)

	set = AddSet(50400,nil,RAID,9,"WR_TR_MELEE_H_09",WARRIOR,MELEE,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48388,48390,48386,48387,48389)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48393,48395,48391,48392,48394)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48398,48400,48396,48397,48399)

	set = AddSet(50400,nil,RAID,9,"WR_TR_TANK_H_09",WARRIOR,TANK,HORDE)
				AddVariant(50400,nil,RAID,set,"VENDOR",OBTAIN,TRANSMOG,48458,48460,48456,48457,48459)
				AddVariant(50400,nil,RAID,set,"NORMAL",OBTAIN,TRANSMOG,48463,48465,48461,48462,48464)
				AddVariant(50400,nil,RAID,set,"HEROIC",OBTAIN,TRANSMOG,48468,48470,48466,48467,48469)
	
	-- Tier 8
	set = AddSet(50400,nil,RAID,8,"WR_TR_MELEE_08",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45431,45433,45429,45430,45432)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46151,46149,46146,46148,46150)

	set = AddSet(50400,nil,RAID,8,"WR_TR_TANK_08",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,45425,45428,45424,45426,45427)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,46166,46167,46162,46164,46169)

	-- Tier 7
	set = AddSet(50400,nil,RAID,7,"WR_TR_MELEE_07",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39605,39608,39606,39609,39607)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40528,40530,40525,40527,40529)
	
	set = AddSet(50400,nil,RAID,7,"WR_TR_TANK_07",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"PLAYER10",OBTAIN,TRANSMOG,39610,39613,39611,39622,39612)
				AddVariant(50400,nil,RAID,set,"PLAYER25",OBTAIN,TRANSMOG,40546,40548,40544,40545,40547)
	
	-- Tier 6
	set = AddSet(50400,nil,RAID,6,"WR_TR_MELEE_06",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_MELEE_06",OBTAIN,TRANSMOG,30972,30979,30975,34441,30969,34546,30977,34569)
				
	set = AddSet(50400,nil,RAID,6,"WR_TR_TANK_06",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_TANK_06",OBTAIN,TRANSMOG,30974,30980,30976,34442,30970,34547,30978,34568)
	
	-- Tier 5
	set = AddSet(50400,nil,RAID,5,"WR_TR_MELEE_05",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_MELEE_05",OBTAIN,TRANSMOG,30120,30122,30118,30119,30121)
				
	set = AddSet(50400,nil,RAID,5,"WR_TR_TANK_05",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_TANK_05",OBTAIN,TRANSMOG,30115,30117,30113,30114,30116)
	
	-- Tier 4
	set = AddSet(50400,nil,RAID,4,"WR_TR_MELEE_04",WARRIOR,MELEE,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_MELEE_04",OBTAIN,TRANSMOG,29021,29023,29019,29020,29022)
				
	set = AddSet(50400,nil,RAID,4,"WR_TR_TANK_04",WARRIOR,TANK,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_TANK_04",OBTAIN,TRANSMOG,29011,29016,29012,29017,29015)
	
	-- Tier 3
	set = AddSet(50400,nil,RAID,3,"WR_TR_03",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_03",NOOBTAIN,TRANSMOG,22418,22419,22416,22423,22421,22422,22417,22420,23059)
	
	-- Tier 2
	set = AddSet(50400,nil,RAID,2,"WR_TR_02",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_02",OBTAIN,TRANSMOG,16963,16961,16966,16959,16964,16960,16962,16965)
	
	-- Tier 1
	set = AddSet(50400,nil,RAID,1,"WR_TR_01",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,RAID,set,"WR_TR_01",NOOBTAIN,TRANSMOG,16866,16868,16865,16861,16863,16864,16867,16862)
	
	-- Challenge Dungeon Sets
	set = AddSet(50400,nil,CHALLENGE,1,"WR_CD_90",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,CHALLENGE,set,"WR_CD_90",NOOBTAIN,TRANSMOG,90151,90153,90149,90154,90150,90147,90152,90148)
	
	-- Dungeon Sets
	set = AddSet(50400,nil,DUNGEON,30,"WR_DG_03",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"WR_DG_03",OBTAIN,TRANSMOG,28350,27803,28205,27475,27977)
				
	set = AddSet(50400,nil,DUNGEON,31,"DG_PLATE_03",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"DG_PLATE_03",OBTAIN,TRANSMOG,28225,27771,28403,27497,27870)
	
	set = AddSet(50400,nil,DUNGEON,22,"WR_DG_AQ_2",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"WR_DG_AQ_2",OBTAIN,TRANSMOG,21329,21330,21331,21332,21333)
	
	set = AddSet(50400,nil,DUNGEON,21,"WR_DG_AQ_1",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"WR_DG_AQ_1",OBTAIN,TRANSMOG,21392,21394,21393)
	
	set = AddSet(50400,nil,DUNGEON,20,"WR_DG_02",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78330,78332,78328,78327,78329,78333,78331,78326)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,21999,22001,21997,21996,21998,21994,22000,21995)
	
	set = AddSet(50400,nil,DUNGEON,10,"WR_DG_01",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,DUNGEON,set,"REPLICA",OBTAIN,TRANSMOG,78322,78325,78323,78321,78320,78319,78324,78318)
				AddVariant(50400,nil,DUNGEON,set,"ORIGINAL",NOOBTAIN,TRANSMOG,16731,16733,16730,16735,16737,16736,16732,16734)
	
	-- PvP
	set = AddSet(60200,nil,PVP,18,"WR_PVP_18",WARRIOR,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126265,126267,126263,126264,126266)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126174,126176,126172,126173,126175)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125996,125998,125994,125995,125997)
				
	set = AddSet(60200,nil,PVP,18,"WR_PVP_18",WARRIOR,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,126742,126744,126740,126741,126743)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,126651,126653,126649,126650,126652)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,126473,126475,126471,126472,126474)
				
	set = AddSet(60200,nil,PVP,17,"WR_PVP_17",WARRIOR,ANY,ALLIANCE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125151,125153,125149,125150,125152)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125060,125062,125058,125059,125061)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,124882,124884,124880,124881,124883)
				
	set = AddSet(60200,nil,PVP,17,"WR_PVP_17",WARRIOR,ANY,HORDE)
				AddVariant(60200,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,125628,125630,125626,125627,125629)
				AddVariant(60200,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,125537,125539,125535,125536,125538)
				AddVariant(60200,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,125359,125361,125357,125358,125360)
				
	set = AddSet(50400,nil,PVP,16,"WR_PVP_16",WARRIOR,ANY,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,115265,115267,115263,115264,115266)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,115168,115170,115166,115167,115169)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,115768,115770,115766,115767,115769)
				
	set = AddSet(50400,nil,PVP,16,"WR_PVP_16",WARRIOR,ANY,HORDE)
				AddVariant(50400,nil,PVP,set,"ASPIRANT",OBTAIN,TRANSMOG,120042,120044,120040,120041,120043)
				AddVariant(50400,nil,PVP,set,"COMBATANT",OBTAIN,TRANSMOG,119945,119947,119943,119944,119946)
				AddVariant(50400,nil,PVP,set,"GLADIATOR",OBTAIN,TRANSMOG,111241,111243,111239,111240,111242)
				
	set = AddSet(50400,nil,PVP,15,"WR_PVP_MELEE_15",WARRIOR,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,102619,102685,102728,102618,102732)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103130,103132,103128,103129,103074,103131,103075)
				
	set = AddSet(50400,nil,PVP,15,"WR_PVP_MELEE_15",WARRIOR,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,103527,103529,103525,103526,103528)
				AddVariant(50400,nil,PVP,set,"ELITE",NOOBTAIN,TRANSMOG,103130,103132,103128,103129,103074,103131,103075)
				
	set = AddSet(50400,nil,PVP,14,"WR_PVP_MELEE_14",WARRIOR,MELEE,ALLIANCE)
				AddVariant(50400,nil,PVP,set,"ALLIANCE",OBTAIN,TRANSMOG,100524,100528,100520,100522,100526)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100525,100529,100521,100523,100527)
				
	set = AddSet(50400,nil,PVP,14,"WR_PVP_MELEE_14",WARRIOR,MELEE,HORDE)
				AddVariant(50400,nil,PVP,set,"HORDE",OBTAIN,TRANSMOG,100562,100631,100674,100561,100678)
				AddVariant(50400,nil,PVP,set,"ELITE",OBTAIN,TRANSMOG,100525,100529,100521,100523,100527)
				
end

local function AddGarrisonSets()
	local set = ""
	
	set = AddSet(60000,nil,GARRISON,602,"GA_BWM_SET_100",ANY,ANY,ANY)
				AddVariant(60000,nil,GARRISON,set,"CLOTH",OBTAIN,TRANSMOG,113801,113803,113799,113804,113800,113797,113802,113798)
				AddVariant(60000,nil,GARRISON,set,"LEATHER",OBTAIN,TRANSMOG,113793,113795,113791,113796,113792,113789,113794,113790)
				AddVariant(60000,nil,GARRISON,set,"MAIL",OBTAIN,TRANSMOG,113817,113819,113815,113820,113816,113813,113818,113814)
				AddVariant(60000,nil,GARRISON,set,"PLATE",OBTAIN,TRANSMOG,113809,113811,113807,113812,113808,113805,113810,113806)
	
	set = AddSet(60000,nil,GARRISON,601,"GA_ALLIANCE_SET",ANY,ANY,ALLIANCE)
				AddVariant(60000,nil,GARRISON,set,"GA_ALLIANCE_SET",OBTAIN,TRANSMOG,117406,117407,117408,117409,117410,117411,117412)
	
	set = AddSet(60000,nil,GARRISON,601,"GA_HORDE_SET",ANY,ANY,HORDE)
				AddVariant(60000,nil,GARRISON,set,"GA_HORDE_SET",OBTAIN,TRANSMOG,118366,118367,118368,118369,118370,118371)

end

local function AddHolidaySets()
	local set = ""
	
	set = AddSet(50400,nil,HOLIDAY,1103271,"HO_FESTIVE_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"GREEN",OBTAIN,NOTRANSMOG,21157)
				AddVariant(50400,nil,HOLIDAY,set,"PINK",OBTAIN,NOTRANSMOG,21538)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",OBTAIN,NOTRANSMOG,21539)
				AddVariant(50400,nil,HOLIDAY,set,"RED",OBTAIN,NOTRANSMOG,21154)
				
	set = AddSet(50400,nil,HOLIDAY,1103272,"HO_FESTIVE_SUIT",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",OBTAIN,NOTRANSMOG,21541)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",OBTAIN,NOTRANSMOG,21544)
				AddVariant(50400,nil,HOLIDAY,set,"TEAL",OBTAIN,NOTRANSMOG,21543)
				AddVariant(50400,nil,HOLIDAY,set,"RED",OBTAIN,NOTRANSMOG,21542)
				
	set = AddSet(50400,nil,HOLIDAY,1203351,"HO_LOVELY_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",OBTAIN,NOTRANSMOG,22279)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",OBTAIN,NOTRANSMOG,22278)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",OBTAIN,NOTRANSMOG,22280)
				AddVariant(50400,nil,HOLIDAY,set,"RED",22276)
				
	set = AddSet(50400,nil,HOLIDAY,1203352,"HO_DINNER_SUIT",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",OBTAIN,NOTRANSMOG,22281)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",OBTAIN,NOTRANSMOG,22282)
				AddVariant(50400,nil,HOLIDAY,set,"RED",OBTAIN,NOTRANSMOG,22277)
				
	set = AddSet(50400,nil,HOLIDAY,1401811,"HO_ELEGANT_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"HO_ELEGANT_DRESS",OBTAIN,NOTRANSMOG,19028)
				
	set = AddSet(50400,nil,HOLIDAY,1401812,"HO_TUXEDO",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",OBTAIN,NOTRANSMOG,6833,6835)
				
	set = AddSet(50400,nil,HOLIDAY,1603411,"HO_MIDSUMMER_REVELER",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"RED",OBTAIN,NOTRANSMOG,23324,34685,34683)
				
	set = AddSet(50400,nil,HOLIDAY,1903721,"HO_BREWFEST_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",OBTAIN,NOTRANSMOG,33968,33863,33966)
				AddVariant(50400,nil,HOLIDAY,set,"BROWN",OBTAIN,NOTRANSMOG,33864,33863,33966)
				AddVariant(50400,nil,HOLIDAY,set,"GREEN",OBTAIN,NOTRANSMOG,33967,33863,33966)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",OBTAIN,NOTRANSMOG,33969,33863,33966)
				
	set = AddSet(50400,nil,HOLIDAY,1903722,"HO_BREWFEST_REGALIA",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLUE",OBTAIN,NOTRANSMOG,33968,33862,33868)
				AddVariant(50400,nil,HOLIDAY,set,"BROWN",OBTAIN,NOTRANSMOG,33864,33862,33868)
				AddVariant(50400,nil,HOLIDAY,set,"GREEN",OBTAIN,NOTRANSMOG,33967,33862,33868)
				AddVariant(50400,nil,HOLIDAY,set,"PURPLE",OBTAIN,NOTRANSMOG,33969,33862,33868)
	
	set = AddSet(50400,nil,HOLIDAY,2003241,"HO_HALLOWED_HELM",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",OBTAIN,NOTRANSMOG,33292)
	
	set = AddSet(50400,nil,HOLIDAY,2003242,"HO_HORSEMANS_HOOD",DEATHKNIGHT,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"L90",OBTAIN,NOTRANSMOG,87569)
				AddVariant(50400,nil,HOLIDAY,set,"L100",OBTAIN,NOTRANSMOG,117355)
	
	set = AddSet(50400,nil,HOLIDAY,2003242,"HO_HORSEMANS_HOOD",PALADIN,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"L90",OBTAIN,NOTRANSMOG,87569)
				AddVariant(50400,nil,HOLIDAY,set,"L100",OBTAIN,NOTRANSMOG,117355)
	
	set = AddSet(50400,nil,HOLIDAY,2003242,"HO_HORSEMANS_HOOD",WARRIOR,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"L90",OBTAIN,NOTRANSMOG,87569)
				AddVariant(50400,nil,HOLIDAY,set,"L100",OBTAIN,NOTRANSMOG,117355)
	
	set = AddSet(50400,nil,HOLIDAY,2003243,"HO_HORSEMANS_SLICER",ROGUE,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"L90",OBTAIN,NOTRANSMOG,87570)
				AddVariant(50400,nil,HOLIDAY,set,"L100",OBTAIN,NOTRANSMOG,117356)
	
	set = AddSet(50400,nil,HOLIDAY,2104041,"HO_PILGRIMS_ATTIRE",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",OBTAIN,NOTRANSMOG,46723,46800,44788)
				AddVariant(50400,nil,HOLIDAY,set,"FINE",OBTAIN,NOTRANSMOG,116401,46800,44788)
	
	set = AddSet(50400,nil,HOLIDAY,2104042,"HO_PILGRIMS_DRESS",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"BLACK",OBTAIN,NOTRANSMOG,46723,44785,44788)
				AddVariant(50400,nil,HOLIDAY,set,"FINE",OBTAIN,NOTRANSMOG,116401,44785,44788)
	
	set = AddSet(50400,nil,HOLIDAY,2201411,"HO_WINTER_GARB",ANY,ANY,ANY)
				AddVariant(50400,nil,HOLIDAY,set,"GREEN",OBTAIN,NOTRANSMOG,21525,34087,34086)
				AddVariant(50400,nil,HOLIDAY,set,"RED",OBTAIN,NOTRANSMOG,21524,34085,34086)
			
end

local function AddOtherSets()
	local set = ""
	
	set = AddSet(60200,nil,OTHER,10070501,"OT_ELR_100",ANY,ANY,ANY)
				AddVariant(60200,nil,OTHER,set,"OT_ELR_100",OBTAIN,TRANSMOG,124159,124176,124200)

end

--
-- Setup Database
--

function SetCollectorSetupDB(release, override)
	if SetCollectorDB == nil or SetCollectorDB.version ~= DB_VERSION or override == true then
		
		-- Clear previous DB to avoid duplicate entries
		--SetCollectorDB = { version = DB_VERSION, release = release }
		
		CreateCollections(DB_VERSION, release)
	
		-- Add Sets to Collections
		AddDeathKnightSets()
		AddDruidSets()
		AddHunterSets()
		AddMageSets()
		AddMonkSets()
		AddPaladinSets()
		AddPriestSets()
		AddRogueSets()
		AddShamanSets()
		AddWarlockSets()
		AddWarriorSets()
		AddGarrisonSets()
		AddHolidaySets()
		AddOtherSets()
		
		if (override == true) then print(_L["DB_UPGRADED"]) end
	end
end

function SetCollectorSetupCharacterDB(class, release, override)
	if SetCollectorCharacterDB == nil or override == true then
		SetCollectorCharacterDB = { version = DB_VERSION, release = release, minimap = { hide = false }, Sets = { }, Items = { }, Filters = { favorites = false, obtainable = false, transmog = false, spec = 0 } }
		for i=1, #SetCollectorDB do
			for j in pairs(SetCollectorDB[i].Sets) do
				if ( SetCollectorDB[i].Sets[j].Class == class or SetCollectorDB[i].Sets[j].Class == ANY.Description ) then
					-- Set Info
					SetCollectorCharacterDB.Sets[j] = { Favorite = false, Tracking = false, Variants = {} }
					-- Item Info
					for k=1, #SetCollectorDB[i].Sets[j].Variants do
						if ( SetCollectorCharacterDB.Sets[j].Variants[k] ) then
							SetCollectorCharacterDB.Sets[j].Variants[k].Favorite = false
						else
							SetCollectorCharacterDB.Sets[j].Variants[k] = { Favorite = false }
						end
						for l=1, #SetCollectorDB[i].Sets[j].Variants[k].Items do
							local itemID = SetCollectorDB[i].Sets[j].Variants[k].Items[l]
							local itemCheck = itemID
							SetCollectorCharacterDB.Items[itemID] = { Count = 0 }
							local count = SetCollectorCharacterDB.Items[itemID].Count
						end
					end
				end
			end
		end
		if (override == true) then print("|cffff6666".._L["CHAR_DB_UPGRADED"].."|r") end
		
	elseif SetCollectorCharacterDB.release < 30 then
		SetCollectorCharacterDB = { version = DB_VERSION, release = release, minimap = { hide = false }, Sets = { }, Items = { }, Filters = { favorites = false, obtainable = false, transmog = false, spec = 0 } }
		for i=1, #SetCollectorDB do
			for j in pairs(SetCollectorDB[i].Sets) do
				if ( SetCollectorDB[i].Sets[j].Class == class or SetCollectorDB[i].Sets[j].Class == ANY.Description ) then
					-- Set Info
					SetCollectorCharacterDB.Sets[j] = { Favorite = false, Tracking = false, Variants = {} }
					-- Item Info
					for k=1, #SetCollectorDB[i].Sets[j].Variants do
						if ( SetCollectorCharacterDB.Sets[j].Variants[k] ) then
							SetCollectorCharacterDB.Sets[j].Variants[k].Favorite = false
						else
							SetCollectorCharacterDB.Sets[j].Variants[k] = { Favorite = false }
						end
						for l=1, #SetCollectorDB[i].Sets[j].Variants[k].Items do
							local itemID = SetCollectorDB[i].Sets[j].Variants[k].Items[l]
							SetCollectorCharacterDB.Items[itemID] = { Count = 0 }
						end
					end
				end
			end
		end
		print("|cff6666ff".._L["CHAR_DB_UPGRADED"].."|r")
		
	elseif SetCollectorCharacterDB.version ~= DB_VERSION or SetCollectorCharacterDB.release < release then
		SetCollectorCharacterDB.version = DB_VERSION
		SetCollectorCharacterDB.release = release
		if not SetCollectorCharacterDB.Filters then
			 SetCollectorCharacterDB.Filters = { favorites = false, obtainable = false, transmog = false, spec = 0 }
		end
		local added = 0
		for i=1, #SetCollectorDB do
			for j in pairs(SetCollectorDB[i].Sets) do
				if ( SetCollectorDB[i].Sets[j].Class == class or SetCollectorDB[i].Sets[j].Class == ANY.Description ) then
					-- Set Info
					if ( not SetCollectorCharacterDB.Sets[j] ) then
						SetCollectorCharacterDB.Sets[j] = { Favorite = false, Tracking = false, Variants = {} }
						added = added + 1
					elseif ( not SetCollectorCharacterDB.Sets[j].Variants ) then
						SetCollectorCharacterDB.Sets[j].Variants = {}
					end
					-- Item Info
					for k=1, #SetCollectorDB[i].Sets[j].Variants do
						if ( SetCollectorCharacterDB.Sets[j].Variants[k] ) then
							SetCollectorCharacterDB.Sets[j].Variants[k].Favorite = false
						else
							SetCollectorCharacterDB.Sets[j].Variants[k] = { Favorite = false }
						end
						for l=1, #SetCollectorDB[i].Sets[j].Variants[k].Items do
							local itemID = SetCollectorDB[i].Sets[j].Variants[k].Items[l]
							if ( not SetCollectorCharacterDB.Items[itemID] ) then
								SetCollectorCharacterDB.Items[itemID] = { Count = 0 }
								added = added + 1
							end
						end
					end
				end
			end
		end
		if ( added > 0 ) then
			print("|cff66ff66".._L["CHAR_DB_UPGRADED"].."|r")
		end
	end
	
end